<?php
/**
 * @version 1.1.0 $Id: comments.php 2009-03-25 $
 * @package Joomla
 * @subpackage PhotoMap Gallery
 * @copyright (C) 2009 - 2010 Oh-Taek Im
 * @license GNU/GPL, see LICENCE.php
 * PhotoMap Gallery is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License 2
 * as published by the Free Software Foundation.

 * PhotoMap Gallery is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.

 * You should have received a copy of the GNU General Public License
 * along with PHOTOMAP GALLERY; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 */

defined( '_JEXEC' ) or die( 'Restricted access' );

jimport('joomla.application.component.controller');

/**
 * PhotoMap Gallery Component Comments Controller
 *
 * @package Joomla
 * @subpackage PhotoMap Gallery Component
 * @since 1.0
 */
class photomapgalleryControllerComments extends photomapgalleryController
{
	/**
	 * Constructor
	 *
	 * @since 1.0
	 */
	function __construct()
	{
		parent::__construct();

		// Register Extra task
		$this->registerTask( 'add'  ,		 	'edit' );
		$this->registerTask( 'apply', 			'save' );
		$this->registerTask( 'accesspublic', 	'access' );
		$this->registerTask( 'accessregistered','access' );
		$this->registerTask( 'accessspecial', 	'access' );
	}

	/**
	 * Logic to save a comments
	 *
	 * @access public
	 * @return void
	 * @since 1.0
	 */
	function save()
	{
		// Check for request forgeries
		JRequest::checkToken() or jexit( 'Invalid Token' );
		
		$task		= JRequest::getVar('task');

		//Sanitize
		$post = JRequest::get( 'post' );
		$post['description'] = JRequest::getVar('description', '', 'POST', 'string', JREQUEST_ALLOWRAW);
		
		$model = $this->getModel('commentedit');
		
		if ( $model->store($post) ) {

			switch ($task)
			{
				case 'apply' :
					$link = 'index.php?option=com_photomapgallery&view=commentedit&cid[]='.(int) $model->get('id');
					break;

				default :
					$link = 'index.php?option=com_photomapgallery&view=comments';
					break;
			}
			$msg = JText::_( 'COMMENT SAVED' );
			
/*			//Take care of access levels and state
			$commentsmodel = & $this->getModel('comments');
			$commentsmodel->access($model->get('id'), $model->get('access'));
			
			$pubid = array();
			$pubid[] = $model->get('id');
			if($model->get('published') == 1) {
				$commentsmodel->publish($pubid, 1);
			} else {
				$commentsmodel->publish($pubid, 0);
			}
*/			
			$cache = &JFactory::getCache('com_photomapgallery');
			$cache->clean();

		} else {

			$msg 	= JText::_( 'ERROR SAVING COMMENT' );
			//JError::raiseError( 500, $model->getError() );
			$link 	= 'index.php?option=com_photomapgallery&view=commentedit';
		}

//		$model->checkin();

		$this->setRedirect($link, $msg);
	}

	/**
	 * Logic to publish comments
	 *
	 * @access public
	 * @return void

	 * @since 1.0
	 */
	function publish()
	{
		// Check for request forgeries
		JRequest::checkToken() or jexit( 'Invalid Token' );
		
		$cid 	= JRequest::getVar( 'cid', array(0), 'post', 'array' );

		if (!is_array( $cid ) || count( $cid ) < 1) {
			$msg = '';
			JError::raiseWarning(500, JText::_( 'SELECT ITEM PUBLISH' ) );
		} else {

			$model = $this->getModel('comments');

			if(!$model->publish($cid, 1)) {
				JError::raiseError(500, $model->getError());
			}

			$msg 	= JText::_( 'COMMENTS PUBLISHED');
		
			$cache = &JFactory::getCache('com_photomapgallery');
			$cache->clean();
		}

		$this->setRedirect( 'index.php?option=com_photomapgallery&view=comments', $msg );
	}

	/**
	 * Logic to unpublish comments
	 *
	 * @access public
	 * @return void
	 * @since 1.0
	 */
	function unpublish()
	{
		// Check for request forgeries
		JRequest::checkToken() or jexit( 'Invalid Token' );
		
		$cid 	= JRequest::getVar( 'cid', array(0), 'post', 'array' );

		if (!is_array( $cid ) || count( $cid ) < 1) {
			$msg = '';
			JError::raiseWarning(500, JText::_( 'SELECT ITEM UNPUBLISH' ) );
		} else {

			$model = $this->getModel('comments');

			if(!$model->publish($cid, 0)) {
				JError::raiseError(500, $model->getError());
			}

			$msg 	= JText::_( 'COMMENTS UNPUBLISHED');
		
			$cache = &JFactory::getCache('com_photomapgallery');
			$cache->clean();
		}
		
		$this->setRedirect( 'index.php?option=com_photomapgallery&view=comments', $msg );
	}

	/**
	 * Logic to orderup a comments
	 *
	 * @access public
	 * @return void;
	 * @since 1.0
	 */
	function orderup()
	{
		// Check for request forgeries
		JRequest::checkToken() or jexit( 'Invalid Token' );
		
		$model = $this->getModel('comments');
		$model->move(-1);
		
		$cache = &JFactory::getCache('com_photomapgallery');
		$cache->clean();
		
		$this->setRedirect( 'index.php?option=com_photomapgallery&view=comments');
	}

	/**
	 * Logic to orderdown a comments
	 *
	 * @access public
	 * @return void
	 * @since 1.0
	 */
	function orderdown()
	{
		// Check for request forgeries
		JRequest::checkToken() or jexit( 'Invalid Token' );
		
		$model = $this->getModel('comments');
		$model->move(1);
		
		$cache = &JFactory::getCache('com_photomapgallery');
		$cache->clean();

		$this->setRedirect( 'index.php?option=com_photomapgallery&view=comments');
	}

	/**
	 * Logic to mass ordering comments
	 *
	 * @access public
	 * @return void
	 * @since 1.0
	 */
	function saveorder()
	{
		// Check for request forgeries
		JRequest::checkToken() or jexit( 'Invalid Token' );
		
		$cid 	= JRequest::getVar( 'cid', array(0), 'post', 'array' );
		$order 	= JRequest::getVar( 'order', array(0), 'post', 'array' );

		$model = $this->getModel('comments');
		if(!$model->saveorder($cid, $order)) {
			$msg = '';
			JError::raiseWarning(500, $model->getError());
		}
		
		$cache = &JFactory::getCache('com_photomapgallery');
		$cache->clean();

		$msg = 'NEW ORDERING SAVED';
		$this->setRedirect( 'index.php?option=com_photomapgallery&view=comments', $msg );
	}

	/**
	 * Logic to delete comments
	 *
	 * @access public
	 * @return void
	 * @since 1.0
	 */
	function remove()
	{
		$cid = JRequest::getVar( 'cid', array(0), 'post', 'array' );

		$total = count( $cid );

		if (!is_array( $cid ) || count( $cid ) < 1) {
			JError::raiseError(500, JText::_( 'Select an item to delete' ) );
		}

		$model = $this->getModel('comments');
		if(!$model->delete($cid)) {
			echo "<script> alert('".$model->getError(true)."'); window.history.go(-1); </script>\n";
		}

		$msg = $total.' '.JText::_( 'COMMENTS DELETED');

		$this->setRedirect( 'index.php?option=com_photomapgallery&view=comments', $msg );
	}

	/**
	 * logic for cancel an action
	 *
	 * @access public
	 * @return void
	 * @since 1.0
	 */
	function cancel()
	{
		// Check for request forgeries
		JRequest::checkToken() or jexit( 'Invalid Token' );
		
		$comments = & JTable::getInstance('g_comments', '');
		$comments->bind(JRequest::get('post'));
		$comments->checkin();

		$this->setRedirect( 'index.php?option=com_photomapgallery&view=comments' );
	}

	/**
	 * Logic to set the comments access level
	 *
	 * @access public
	 * @return void
	 * @since 1.0
	 */
	function access( )
	{
		// Check for request forgeries
		JRequest::checkToken() or jexit( 'Invalid Token' );
		
		$cid		= JRequest::getVar( 'cid', array(0), 'post', 'array' );
		$id			= (int)$cid[0];
		$task		= JRequest::getVar( 'task' );

		if ($task == 'accesspublic') {
			$access = 0;
		} elseif ($task == 'accessregistered') {
			$access = 1;
		} else {
			$access = 2;
		}

		$model = $this->getModel('comments');
		
		if(!$model->access( $id, $access )) {
			JError::raiseError(500, $model->getError());
		} else {
			$cache = &JFactory::getCache('com_photomapgallery');
			$cache->clean();
		}
		
		$this->setRedirect('index.php?option=com_photomapgallery&view=comments' );
	}

	/**
	 * Logic to create the view for the edit comments
	 *
	 * @access public
	 * @return void
	 * @since 1.0
	 */
	function edit( )
	{	
		// Check for request forgeries
		//JRequest::checkToken() or jexit( 'Invalid Token' );
		
		JRequest::setVar( 'view', 'commentedit' );
		JRequest::setVar( 'hidemainmenu', 1 );

		$model 	= $this->getModel('commentedit');
		$user	=& JFactory::getUser();

		// Error if checkedout by another administrator
//		if ($model->isCheckedOut( $user->get('id') )) {
//			$this->setRedirect( 'index.php?option=com_photomapgallery&view=comments', JText::_( 'EDITED BY ANOTHER ADMIN' ) );
//		}

//		$model->checkout( $user->get('id') );
		
		parent::display();
	}
}