<?php
/**
 * @version 1.1.0 $Id: form.php 2009-03-25 $
 * @package Joomla
 * @subpackage PhotoMap Gallery
 * @copyright (C) 2009 - 2010 Oh-Taek Im
 * @license GNU/GPL, see LICENCE.php
 * PhotoMap Gallery is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License 2
 * as published by the Free Software Foundation.

 * PhotoMap Gallery is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.

 * You should have received a copy of the GNU General Public License
 * along with PHOTOMAP GALLERY; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 */
// no direct access
defined( '_JEXEC' ) or die( 'Restricted access' );


require_once ( JPATH_LIBRARIES . DS . 'joomla' . DS . 'html' . DS . 'html' . DS . 'form.php' );

class photomapgalleryForm extends JHTMLForm
{
	function label( $value, $name = '', $required = false, $tip = '', $attribs = null )
	{
		if (is_array($attribs)) {
			$attribs = JArrayHelper::toString($attribs);
		}
		
		$id = $name;
		$id	= str_replace('[','',$id);
		$id	= str_replace(']','',$id);
		$for	= ( !empty($name) ? ' for="' . $id . '"' : '' );
		
		$hastip = '';
		if ( !empty($tip) ) {
			JHTML::_('behavior.tooltip');
			$hastip = ' class="hasTip" title="' . JText::_($value) . '::' . JText::_($tip) . '"';
		}
		
		$star	= ( $required ? '(*) ' : '' );
		
		$html = '<label' . $for . $hastip . $attribs . '>' . $star . JText::_($value) . ':' . '</label>';
		
		return $html;
	}
	
	/**
	 * Input
	 * 
	 * @access	public
	 * @param	string	The input type, among text|password|checkbox|radio|submit|reset|file|hidden|image|button	// @see http://www.w3.org/TR/html401/interact/forms.html#adef-type-INPUT
	 * @param	string	The input name
	 * @param	string	The input value
	 * @param	string	The id tag
	 * @param	array	Associative array of input attributes
	 * 
	 * @todo	Use JArrayHelper::toString() for $attribs ?
	 */
	function input( $type, $name, $value, $idtag = false, $attribs = null )
	{
		if (is_array($attribs)) {
			$attribs['class'] = ( isset( $attribs['class'] ) ? $attribs['class'] : '' ) . ' inputbox';
			$attribs = JArrayHelper::toString($attribs);
		}
		
		$id = $name;
		if ( $idtag ) {
			$id = $idtag;
		}
		
		$id		= str_replace('[','',$id);
		$id		= str_replace(']','',$id);
		
		$html = '<input type="' . $type . '" name="' . $name . '" id="' . $id . '" value="' . $value . '" ' . $attribs . ' />';
		 
		return $html;
	}
	
	/**
	 * Textarea
	 * 
	 * @access	public
	 * @param	string	The input name
	 * @param	string	The input value
	 * @param	string	The id tag
	 * @param	int		The rows value
	 * @param	int		The cols value
	 * @param	array	Associative array of input attributes
	 */
	function textarea( $name, $value, $idtag = false, $cols = 30, $rows = 5, $attribs = null )
	{
		if (is_array($attribs)) {
			$attribs['class'] = ( isset( $attribs['class'] ) ? $attribs['class'] : '' ) . ' inputbox';
			$attribs = JArrayHelper::toString($attribs);
		}
		
		$id = $name;
		if ( $idtag ) {
			$id = $idtag;
		}
		
		$id		= str_replace('[','',$id);
		$id		= str_replace(']','',$id);
		
		$html = '';
		$html .= '<textarea rows="' . $rows . '" cols="' . $cols . '" name="' . $name . '" id="' . $id . '"' . $attribs . '>';
		$html .= 	$value;
		$html .= '</textarea>';
		 
		return $html;
	}
	
	/**
	 * WYSIWYG Editor
	 * 
	 * @param	string	The control name
	 * @param	string	The contents of the text area
	 * @param	string	The width of the text area (px or %)
	 * @param	string	The height of the text area (px or %)
	 * @param	int		The number of columns for the textarea
	 * @param	int		The number of rows for the textarea
	 * @param	boolean	True and the editor buttons will be displayed
	 * @param	array	Associative array of editor parameters
	 */
	function wysiwyg( $name, $html, $width = '100%', $height = '400', $col = '70', $row = '15', $buttons = true, $params = array( 'pagebreak' ) )
	{
		$editor =& JFactory::getEditor();
		return $editor->display( $name, $html, $width, $height, $col, $row, $params );
	}
	
	/**
	 * Checkbox
	 * 
	 * @access	public
	 * @param	string	The input name
	 * @param	string	The input value
	 * @param	string	The selected value
	 * @param	string	The id tag
	 * @param	array	Associative array of input attributes
	 */
	function checkbox( $name, $value = '1', $selected = null, $idtag = false, $attribs = null )
	{
		if (is_array($attribs)) {
			$attribs = JArrayHelper::toString($attribs);
		}
		
		$id = $name;
		if ( $idtag ) {
			$id = $idtag;
		}
		
		$id		= str_replace('[','',$id);
		$id		= str_replace(']','',$id);
		
		// Checked
		if( $selected == $value ) {
			$selected = 'checked="checked" ';
		}
		
		$html = '<input type="checkbox" name="' . $name . '" id="' . $id . '" value="' . $value . '" ' . $selected . $attribs . '/>';
		
		return $html;
	}
	
	/**
	 * Checkbox list
	 * 
	 * @access	public
	 * @param	string	The input name
	 * @param	string	The input value
	 * @param	string	The selected value
	 * @param	string	The id tag
	 * @param	array	Associative array of input attributes
	 */
	function checkboxlist( $arr, $name, $attribs = null, $key = 'value', $text = 'text', $selected = null, $idtag = false, $translate = false )
	{
		reset( $arr );
		$html = '';

		if (is_array($attribs)) {
			$attribs = JArrayHelper::toString($attribs);
		}

		$id_text = $name;
		if ( $idtag ) {
			$id_text = $idtag;
		}
		
		$id_text		= str_replace('[','',$id_text);
		$id_text		= str_replace(']','',$id_text);

		for ($i=0, $n=count( $arr ); $i < $n; $i++ )
		{
			$k	= $arr[$i]->$key;
			$t	= $translate ? JText::_( $arr[$i]->$text ) : $arr[$i]->$text;
			$id	= ( isset($arr[$i]->id) ? @$arr[$i]->id : null);

			$extra	= '';
			$extra	.= $id ? " id=\"" . $arr[$i]->id . "\"" : '';
			if (is_array( $selected ))
			{
				foreach ($selected as $val)
				{
					$k2 = is_object( $val ) ? $val->$key : $val;
					if ($k == $k2)
					{
						$extra .= " checked=\"checked\"";
						break;
					}
				}
			} else {
				$extra .= ($k == $selected ? " checked=\"checked\"" : '');
			}
			$html .= "\n\t<input type=\"checkbox\" name=\"$name\" id=\"$id_text$k\" value=\"".$k."\"$extra $attribs />";
			$html .= "\n\t<label for=\"$id_text$k\">$t</label>";
		}
		$html .= "\n";
		
		return $html;
	}
}
?>
