<?php
/**
 * @version 1.1.0 $Id: galleryitem.php 2009-03-25 $
 * @package Joomla
 * @subpackage PhotoMap Gallery
 * @copyright (C) 2009 - 2010 Oh-Taek Im
 * @license GNU/GPL, see LICENCE.php
 * PhotoMap Gallery is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License 2
 * as published by the Free Software Foundation.
 *
 * PhotoMap Gallery is a derivative work of the excellent QuickFAQ component
 * @copyright (C) 2008 Christoph Lukes
 * see www.schlu.net for more information
 *
 * PhotoMap Gallery is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.

 * You should have received a copy of the GNU General Public License
 * along with PHOTOMAP GALLERY; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 */

// no direct access
defined('_JEXEC') or die('Restricted access');

jimport('joomla.application.component.model');

/**
 * PhotoMap Gallery Component Category Model
 *
 * @package Joomla
 * @subpackage PhotoMap Gallery
 * @since		1.0
 */
class photomapgalleryModelGalleryItem extends JModel
{
	/**
	 * Item data
	 *
	 * @var object
	 */
	var $_item = null;

	/**
	 * Constructor
	 *
	 * @since 1.0
	 */
	function __construct()
	{
		parent::__construct();

		$cid = JRequest::getVar( 'cid', array(0), '', 'array' );
		JArrayHelper::toInteger($cid, array(0));
		$this->setId($cid[0]);
	}

	/**
	 * Method to set the identifier
	 *
	 * @access	public
	 * @param	int item identifier
	 */
	function setId($id)
	{
		// Set item id and wipe data
		$this->_id	    = $id;
		$this->_item	= null;
	}
	
	/**
	 * Overridden get method to get properties from the item
	 *
	 * @access	public
	 * @param	string	$property	The name of the property
	 * @param	mixed	$value		The value of the property to set
	 * @return 	mixed 				The value of the property
	 * @since	1.0
	 */
	function get($property, $default=null)
	{
		if ($this->_loadItem()) {
			if(isset($this->_item->$property)) {
				return $this->_item->$property;
			}
		}
		return $default;
	}

	/**
	 * Method to get item data
	 *
	 * @access	public
	 * @return	array
	 * @since	1.0
	 */
	function &getItem()
	{		
		if ($this->_loadItem())
		{		
			$query = 'SELECT name'
					. ' FROM #__users'
					. ' WHERE id = '. (int) $this->_item->created_by
					;
			$this->_db->setQuery($query);
			$this->_item->creator = $this->_db->loadResult();

			//reduce unneeded query
			if ($this->_item->created_by == $this->_item->modified_by) {
				$this->_item->modifier = $this->_item->creator;
			} else {
				$query = 'SELECT name'
						. ' FROM #__users'
						. ' WHERE id = '. (int) $this->_item->modified_by
						;
				$this->_db->setQuery($query);
				$this->_item->modifier = $this->_db->loadResult();
			}
/*			
			$lang 		= & JFactory::getLanguage();
			$lang_tag 	= $lang->getTag();
			
			$query = 'SELECT *'
					. ' FROM #__g_language'
					. ' WHERE itemid = '. (int) $this->_item->id
					. ' AND language = '. $lang_tag
					;
			$this->_db->setQuery($query);
			$this->_item->languages = $this->_db->loadResult(); */
		}
		else  $this->_initItem();

		return $this->_item;
	}


	/**
	 * Method to load item data
	 *
	 * @access	private
	 * @return	boolean	True on success
	 * @since	1.0
	 */
	function _loadItem()
	{
		// Lets load the item if it doesn't already exist
		if (empty($this->_item))
		{
			$query = 'SELECT i.*, g.name AS gallerygroup'
					. ' FROM #__g_galleryitems AS i'
					. ' LEFT JOIN #__g_user AS u ON u.userID = i.user_id'
					. ' LEFT JOIN #__g_user_groups AS g ON g.id = u.group'
					. ' WHERE i.id = '.$this->_id
					;
			$this->_db->setQuery($query);
			$this->_item = $this->_db->loadObject();
			
			return (boolean) $this->_item;
		}
		return true;
	}

	/**
	 * Method to initialise the item data
	 *
	 * @access	private
	 * @return	boolean	True on success
	 * @since	1.0
	 */
	function _initItem()
	{
		// Lets load the item if it doesn't already exist
		if (empty($this->_item))
		{
			$createdate = & JFactory::getDate();
			$nullDate	= $this->_db->getNullDate();
			
			$item = new stdClass();
			$item->id					= 0;
			$item->user_id				= 0;
			$item->cid[]				= 0;
			$item->title				= null;
			$item->alias				= null;
			$item->filename				= null;
			$item->description			= null;
			$item->imagewidth			= 0;
			$item->imageheight			= 0;
			$item->rate					= 0;
			$item->rate_sum				= 0;
			$item->hits					= 0;
			$item->post_hits			= 0;
			$item->version				= 0;
			$item->meta_description		= null;
			$item->meta_keywords		= null;
			$item->created				= $createdate->toUnix();
			$item->created_by			= null;
			$item->created_by_alias		= '';
			$item->modified				= $nullDate;
			$item->modified_by			= null;
			$item->attribs				= null;
			$item->metadata				= null;
			$item->ordering 			= null;
			$item->published			= 1;
			$item->featured				= 0;
			$item->slideshow			= 0;
			$item->mapdisplay			= 0;
			$item->lat					= null;
			$item->lon					= null;
			$item->zoom					= null;
			$item->maptype				= null;
			$item->exif					= null;
			$this->_item				= $item;
			return (boolean) $this->_item;
		}
		return true;
	}

	/**
	 * Method to checkin/unlock the item
	 *
	 * @access	public
	 * @return	boolean	True on success
	 * @since	1.0
	 */
	function checkin()
	{
		if ($this->_id)
		{
			$item = & JTable::getInstance('g_galleryitems', '');
			return $item->checkin($this->_id);
		}
		return false;
	}

	/**
	 * Method to checkout/lock the item
	 *
	 * @access	public
	 * @param	int	$uid	User ID of the user checking the item out
	 * @return	boolean	True on success
	 * @since	1.0
	 */
	function checkout($uid = null)
	{
		if ($this->_id)
		{
			// Make sure we have a user id to checkout the group with
			if (is_null($uid)) {
				$user	=& JFactory::getUser();
				$uid	= $user->get('id');
			}
			// Lets get to it and checkout the thing...
			$item = & JTable::getInstance('g_galleryitems', '');
			return $item->checkout($uid, $this->_id);
		}
		return false;
	}

	/**
	 * Tests if the item is checked out
	 *
	 * @access	public
	 * @param	int	A user id
	 * @return	boolean	True if checked out
	 * @since	1.0
	 */
	function isCheckedOut( $uid=0 )
	{
		if ($this->_loadItem())
		{
			if ($uid) {
				return ($this->_item->checked_out && $this->_item->checked_out != $uid);
			} else {
				return $this->_item->checked_out;
			}
		} elseif ($this->_id < 1) {
			return false;
		} else {
			JError::raiseWarning( 0, 'UNABLE LOAD DATA');
			return false;
		}
	}

	/**
	 * Method to store the item
	 *
	 * @access	public
	 * @return	boolean	True on success
	 * @since	1.0
	 */
	function store($data)
	{
		// Check for request forgeries
//		JRequest::checkToken() or jexit( 'Invalid Token' );
			
		$item  =& $this->getTable('g_galleryitems', '');
		$user	=& JFactory::getUser();

		$details	= JRequest::getVar( 'details', array(), 'post', 'array');
		$tags 		= JRequest::getVar( 'tag', array(), 'post', 'array');
		$cats 		= JRequest::getVar( 'cid', array(), 'post', 'array');
		
		$title = JRequest::getVar( 'title', null, 'post', 'array');
		$language = JRequest::getVar( 'select_language', null, 'post', 'array');

		//At least one category needs to be assigned
		if (!is_array( $cats ) || count( $cats ) < 1) {
			$this->setError('SELECT CATEGORY');
			return false;
		}
	
		// bind it to the table
		if (!$item->bind($data)) {
			$this->setError($this->_db->getErrorMsg());
			return false;
		}
		
		$item->bind($details);

		// sanitise id field
		$item->id = (int) $item->id;
		
		$nullDate	= $this->_db->getNullDate();

		// Are we saving from an item edit?
		if ($item->id) {
			$item->modified 		= gmdate('Y-m-d H:i:s');
			$item->modified_by 	= $user->get('id');
		} else {
			$item->modified 		= $nullDate;
			$item->modified_by 	= '';

			//get time and userid
			$item->created 			= gmdate('Y-m-d H:i:s');
			$item->created_by		= $user->get('id');
		}
		
		$item->user_id = $user->get('id');
		
		// Get a state and parameter variables from the request
		if (!$data->published) {
			$item->published	= JRequest::getVar( 'published', 0, '', 'int' );
		}
		$item->published	= 1;
		$params		= JRequest::getVar( 'params', null, 'post', 'array' );

		// Build parameter INI string
		if (is_array($params))
		{
			$txt = array ();
			foreach ($params as $k => $v) {
				$txt[] = "$k=$v";
			}
			$item->attribs = implode("\n", $txt);
		}

		// Get metadata string
		$metadata = JRequest::getVar( 'meta', null, 'post', 'array');
		if (is_array($params))
		{
			$txt = array();
			foreach ($metadata as $k => $v) {
				if ($k == 'description') {
					$item->meta_description = $v;
				} elseif ($k == 'keywords') {
					$item->meta_keywords = $v;
				} else {
					$txt[] = "$k=$v";
				}
			}
			$item->metadata = implode("\n", $txt);
		}

		
		if (!$item->id) {
			$item->ordering = $item->getNextOrder();
		}
		
		// Make sure the data is valid
		if (!$item->check()) {
			$this->setError($item->getError());
			return false;
		}
		
		$item->version++;
				
		// Store it in the db
		if (!$item->store()) {
			$this->setError($this->_db->getErrorMsg());
			return false;
		}
		
		$this->_item	=& $item;
		
		$config		= & GUtil::config();
		
		if ($config->default_language != $data['select_language']) {
			$query = 'DELETE FROM #__g_language WHERE itemid = '.$item->id;
			$this->_db->setQuery($query);
			$this->_db->query();
			
			$query = 'INSERT INTO #__g_language (`itemid`, `language`, `title`, `alias`, `description`, `meta_key`, `meta_des`) VALUES('.$item->id.', "'.$data['select_language'].'", "'.$data['title'].'", "'.$data['alias'].'", "'.$data['description'].'", "", "")';
			$this->_db->setQuery($query);
			$this->_db->query();
		}
				
		//store tag relation
		$query = 'DELETE FROM #__g_tags_item_relations WHERE itemid = '.$item->id;
		$this->_db->setQuery($query);
		$this->_db->query();
			
		foreach($tags as $tag)
		{
			$query = 'INSERT INTO #__g_tags_item_relations (`tid`, `itemid`) VALUES(' . $tag . ',' . $item->id . ')';
			$this->_db->setQuery($query);
			$this->_db->query();
		}
		
		//store cat relation
		$query = 'DELETE FROM #__g_cats_item_relations WHERE itemid = '.$item->id;
		$this->_db->setQuery($query);
		$this->_db->query();
			
		foreach($cats as $cat)
		{
			$query = 'INSERT INTO #__g_cats_item_relations (`catid`, `itemid`) VALUES(' . $cat . ',' . $item->id . ')';
			$this->_db->setQuery($query);
			$this->_db->query();
		}
		
		return true;
	}

	/**
	 * Method to reset hits
	 * 
	 * @param int id
	 * @return int
	 * @since 1.0
	 */
	function resetHits($id)
	{
		$row  =& $this->getTable('g_galleryitems', '');
		$row->load($id);
		$row->hits = 0;
		$row->store();
		$row->checkin();
		return $row->id;
	}
	
	/**
	 * Method to reset votes
	 * 
	 * @param int id
	 * @return int
	 * @since 1.0
	 */
	function resetVotes($id)
	{
		$row  =& $this->getTable('g_galleryitems', '');
		$row->load($id);
		$row->rate = 0;
		$row->rate_sum = 0;
		$row->store();
		$row->checkin();
		return $row->id;
	}
	
	/**
	 * Method to reset hits
	 * 
	 * @param int id
	 * @return object
	 * @since 1.0
	 */
	function getvotes($id)
	{
		$query = 'SELECT rate, rate_sum FROM #__g_galleryitems WHERE id = '.(int)$id;
		$this->_db->setQuery($query);
		$votes = $this->_db->loadObjectlist();
		
		return $votes;
	}
	
	/**
	 * Method to get hits
	 * 
	 * @param int id
	 * @return int
	 * @since 1.0
	 */
	function gethits($id)
	{
		$query = 'SELECT hits FROM #__g_galleryitems WHERE id = '.(int)$id;
		$this->_db->setQuery($query);
		$hits = $this->_db->loadResult();
		
		return $hits;
	}
	
	function gettags()
	{
		$query = 'SELECT * FROM #__g_tags ORDER BY name';
		$this->_db->setQuery($query);
		$tags = $this->_db->loadObjectlist();
		return $tags;
	}
	
	function getusedtags($id)
	{
		$query = 'SELECT DISTINCT tid FROM #__g_tags_item_relations WHERE itemid = ' . (int)$id;
		$this->_db->setQuery($query);
		$used = $this->_db->loadResultArray();
		return $used;
	}
	/**
	 * Method to get used categories when performing an edit action
	 * 
	 * @return array
	 * @since 1.0
	 */
	function getCatsselected()
	{
		$query = 'SELECT DISTINCT catid FROM #__g_cats_item_relations WHERE itemid = ' . (int)$this->_id;
		$this->_db->setQuery($query);
		$used = $this->_db->loadResultArray();
		return $used;
	}
}
?>