<?php
/**
 * @version 1.1.0 $Id: galleryitems.php 2009-03-25 $
 * @package Joomla
 * @subpackage PhotoMap Gallery
 * @copyright (C) 2009 - 2010 Oh-Taek Im
 * @license GNU/GPL, see LICENCE.php
 * PhotoMap Gallery is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License 2
 * as published by the Free Software Foundation.
 *
 * PhotoMap Gallery is a derivative work of the excellent QuickFAQ component
 * @copyright (C) 2008 Christoph Lukes
 * see www.schlu.net for more information
 *
 * PhotoMap Gallery is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.

 * You should have received a copy of the GNU General Public License
 * along with PHOTOMAP GALLERY; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 */

// no direct access
defined('_JEXEC') or die('Restricted access');

jimport('joomla.application.component.model');

/**
 * PhotoMap Gallery Component Items Model
 *
 * @package Joomla
 * @subpackage PhotoMap Gallery
 * @since		1.0
 */
class photomapgalleryModelGalleryItems extends JModel
{
	/**
	 * Items data
	 *
	 * @var object
	 */
	var $_data = null;

	/**
	 * Items total
	 *
	 * @var integer
	 */
	var $_total = null;

	/**
	 * Pagination object
	 *
	 * @var object
	 */
	var $_pagination = null;

	/**
	 * Item id
	 *
	 * @var int
	 */
	var $_id = null;

	/**
	 * Constructor
	 *
	 * @since 1.0
	 */
	function __construct()
	{
		parent::__construct();

		global $mainframe, $option;

		$limit		= $mainframe->getUserStateFromRequest( $option.'.limit', 'limit', $mainframe->getCfg('list_limit'), 'int');
		$limitstart = $mainframe->getUserStateFromRequest( $option.'.limitstart', 'limitstart', 0, 'int' );

		$this->setState('limit', $limit);
		$this->setState('limitstart', $limitstart);

		$array = JRequest::getVar('cid',  0, '', 'array');
		$this->setId((int)$array[0]);
	}

	/**
	 * Method to set the Items identifier
	 *
	 * @access	public
	 * @param	int Category identifier
	 */
	function setId($id)
	{
		// Set id and wipe data
		$this->_id	 = $id;
		$this->_data = null;
	}

	/**
	 * Method to get item data
	 *
	 * @access public
	 * @return object
	 */
	function getData()
	{
		// Lets load the Items if it doesn't already exist
		if (empty($this->_data))
		{
			$query = $this->_buildQuery();
			$this->_data = $this->_getList($query, $this->getState('limitstart'), $this->getState('limit'));
		}
		
		return $this->_data;
	}

	/**
	 * Method to get the total nr of the Items
	 *
	 * @access public
	 * @return integer
	 */
	function getTotal()
	{
		// Lets load the Items if it doesn't already exist
		if (empty($this->_total))
		{
			$query = $this->_buildQuery();
			$this->_total = $this->_getListCount($query);
		}

		return $this->_total;
	}

	/**
	 * Method to get a pagination object for the Items
	 *
	 * @access public
	 * @return object
	 */
	function getPagination()
	{
		// Lets load the Items if it doesn't already exist
		if (empty($this->_pagination))
		{
			jimport('joomla.html.pagination');
			$this->_pagination = new JPagination( $this->getTotal(), $this->getState('limitstart'), $this->getState('limit') );
		}

		return $this->_pagination;
	}

	/**
	 * Method to build the query for the Items
	 *
	 * @access private
	 * @return string
	 * @since 1.0
	 */
	function _buildQuery()
	{
		// Get the WHERE and ORDER BY clauses for the query
		$where		= $this->_buildContentWhere();
		$orderby	= $this->_buildContentOrderBy();

		$query = 'SELECT DISTINCT rel.itemid, i.*, u.name AS editor,  (i.rate / (i.rate + i.rate_sum) ) * 100 AS votes, g.name AS gallerygroup, c.id AS catid, c.title AS cattitle, c.directory AS directory'
					. ' FROM #__g_galleryitems AS i'
					. ' LEFT JOIN #__g_cats_item_relations AS rel ON rel.itemid = i.id'
					. ' LEFT JOIN #__g_categories AS c ON c.id = rel.catid'
					. ' LEFT JOIN #__g_user AS gu ON gu.userID = c.userid'
					. ' LEFT JOIN #__g_user_groups AS g ON g.id = gu.group'
					. ' LEFT JOIN #__users AS u ON u.id = i.checked_out'
					. $where
					. $orderby
					;

		return $query;
	}

	/**
	 * Method to build the orderby clause of the query for the Items
	 *
	 * @access private
	 * @return string
	 * @since 1.0
	 */
	function _buildContentOrderBy()
	{
		global $mainframe, $option;

		$filter_order		= $mainframe->getUserStateFromRequest( $option.'.galleryitems.filter_order', 'filter_order', 'i.ordering', 'cmd' );
		$filter_order_Dir	= $mainframe->getUserStateFromRequest( $option.'.galleryitems.filter_order_Dir', 'filter_order_Dir', '', 'word' );

		$orderby 	= ' ORDER BY '.$filter_order.' '.$filter_order_Dir.', i.ordering';

		return $orderby;
	}

	/**
	 * Method to build the where clause of the query for the Items
	 *
	 * @access private
	 * @return string
	 * @since 1.0
	 */
	function _buildContentWhere()
	{
		global $mainframe, $option;

		$filter_category 	= $mainframe->getUserStateFromRequest($option.'.galleryitems.filter_category', 'filter_category', 0, 'int');
		$filter_state 		= $mainframe->getUserStateFromRequest( $option.'.galleryitems.filter_state', 'filter_state', '', 'word' );
		$search 			= $mainframe->getUserStateFromRequest( $option.'.galleryitems.search', 'search', '', 'string' );
		$search 			= $this->_db->getEscaped( trim(JString::strtolower( $search ) ) );

		$where = array();
		
		$where[] = ' i.published != -1';
		
		if ($filter_category > 0) {
			$where[] = ' c.id = '.$filter_category ;
		}

		if ($search) {
			$where[] = ' LOWER(i.title) LIKE '.$this->_db->Quote( '%'.$this->_db->getEscaped( $search, true ).'%', false );
		}

		$where 		= ( count( $where ) ? ' WHERE ' . implode( ' AND ', $where ) : '' );
		
		return $where;
	}

	function publish($cid) {
	
		global $mainframe;

		$user 	=& JFactory::getUser();
		if (count( $cid )) {
			JArrayHelper::toInteger($cid);
			$cids = implode( ',', $cid );

			$query = 'UPDATE #__g_galleryitems'
				. ' SET published = 1'
				. ' WHERE id IN ( '.$cids.' )'
				. ' AND ( checked_out = 0 OR ( checked_out = '.(int) $user->get('id').' ) )';
				
			$this->_db->setQuery( $query );
			if (!$this->_db->query()) {
				$this->setError($this->_db->getErrorMsg());
				return false;
			}
		}
		
		$cache = & JFactory::getCache('com_photomapgallery');
		$cache->clean();
		$mainframe->redirect('index.php?option=com_photomapgallery&view=galleryitems');
	}

	function unpublish($cid) {
	
		global $mainframe;

		$user 	=& JFactory::getUser();
		if (count( $cid )) {
			JArrayHelper::toInteger($cid);
			$cids = implode( ',', $cid );

			$query = 'UPDATE #__g_galleryitems'
				. ' SET published = 0'
				. ' WHERE id IN ( '.$cids.' )'
				. ' AND ( checked_out = 0 OR ( checked_out = '.(int) $user->get('id').' ) )';
				
			$this->_db->setQuery( $query );
			if (!$this->_db->query()) {
				$this->setError($this->_db->getErrorMsg());
				return false;
			}
		}
		
		$cache = & JFactory::getCache('com_photomapgallery');
		$cache->clean();
		$mainframe->redirect('index.php?option=com_photomapgallery&view=galleryitems');
	}
	
	/**
	 * Method to move a Item
	 *
	 * @access	public
	 * @return	boolean	True on success
	 * @since	1.0
	 */
	function move($direction)
	{
		$row =& JTable::getInstance('g_galleryitems', '');

		if (!$row->load( $this->_id ) ) {
			$this->setError($this->_db->getErrorMsg());
			return false;
		}

		if (!$row->move( $direction )) {
			$this->setError($this->_db->getErrorMsg());
			return false;
		}

		return true;
	}

	/**
	 * Method to order Items
	 *
	 * @access	public
	 * @return	boolean	True on success
	 * @since	1.0
	 */
	function saveorder($cid = array(), $order)
	{
		$row =& JTable::getInstance('g_galleryitems', '');
		
		// update ordering values
		for( $i=0; $i < count($cid); $i++ )
		{
			$row->load( (int) $cid[$i] );

			if ($row->ordering != $order[$i])
			{
				$row->ordering = $order[$i];
				if (!$row->store()) {
					$this->setError($this->_db->getErrorMsg());
					return false;
				}
			}
		}

		return true;
	}

	/**
	 * Method to remove a gallery item
	 *
	 * @access	public
	 * @return	boolean	True on success
	 * @since	1.0
	 */
	function delete($cid = array())
	{	
		$total 	= count( $cid );

		if ($total)
		{
			for ($i = 0; $i < $total; $i++) {
				$category[$i]	= $this->getCategory($cid[$i]);

				$query = 'SELECT filename FROM #__g_galleryitems WHERE id IN ( '.$cid[$i].' )';
				$this->_db->setQuery($query);
				$fileObject = $this->_db->loadObject();

				//remove assigned category references
				$query = 'DELETE FROM #__g_cats_item_relations'
						.' WHERE itemid IN ('. $cid[$i] .')'
						;
				$this->_db->setQuery($query);
	
				if(!$this->_db->query()) {
					$this->setError($this->_db->getErrorMsg());
					return false;
				}
				
				$query = 'DELETE FROM #__g_galleryitems'
						. ' WHERE id IN ('. $cid[$i] .')'
						;
	
				$this->_db->setQuery( $query );
				
				if(!$this->_db->query()) {
					$this->setError($this->_db->getErrorMsg());
					JError::raiseNotice(500, JText::_('QUERY ERROR'));
					return false;
				}
			
				$directory = $category[$i]->directory;
				
				$dir = GALLERY_IMAGES_ORIGINAL.DS.$directory.DS.$fileObject->filename;
				$album_dir = GALLERY_IMAGES_ALBUM_URL.DS.$directory.DS.$fileObject->filename;
				$resize_dir = GALLERY_IMAGES_RESIZED_URL.DS.$directory.DS.$fileObject->filename;
				$thumb_dir = GALLERY_IMAGES_THUMBNAIL_URL.DS.$directory.DS.$fileObject->filename;
				
				if (JFile::exists($dir)) {
					JFile::delete($dir);
				}

				if (JFile::exists($album_dir)) {
					JFile::delete($album_dir);
				}

				if (JFile::exists($resize_dir)) {
					JFile::delete($resize_dir);
				}

				if (JFile::exists($thumb_dir)) {
					JFile::delete($thumb_dir);
				}
			}
			
			return true;
		}
		return false;
	}
	
	/**
	 * Method to fetch the assigned categories
	 *
	 * @access	public
	 * @return	object
	 * @since	1.0
	 */
	function getCategories($id)
	{
		$query = 'SELECT DISTINCT c.id, c.title'
				. ' FROM #__g_categories AS c'
				. ' LEFT JOIN #__g_cats_item_relations AS rel ON rel.catid = c.id'
				. ' WHERE rel.itemid = '.(int)$id
				;
	
		$this->_db->setQuery( $query );

		$this->_cats = $this->_db->loadObjectList();

		return $this->_cats;
	}
	
	function getCategory($id)
	{
		$query = 'SELECT DISTINCT c.id, c.title, c.directory, g.name AS groupname'
				. ' FROM #__g_categories AS c'
				. ' LEFT JOIN #__g_cats_item_relations AS rel ON rel.catid = c.id'
				. ' LEFT JOIN #__g_user AS u ON u.userID = c.userid'
				. ' LEFT JOIN #__g_user_groups AS g ON g.id = u.group'
				. ' WHERE rel.itemid = '.(int)$id
				;
	
		$this->_db->setQuery( $query );

		$category = $this->_db->loadObject();

		return $category;
	}
	
	function removeFile($file) {
		if (unlink($file)) {
			return true;
		}
		else {
			return false;
		}
	}
}
?>