<?php
/**
 * @version 1.1 beta $Id: galleryitems.php 2009-12-28 $
 * @package Joomla
 * @subpackage PhotoMap Gallery
 * @copyright (C) 2009 - 2010 Oh-Taek Im - www.photoindochina.com
 * @license GNU/GPL v2
 * 
 * PhotoMap Gallery is a derivative work of the excellent QuickFAQ component
 * @copyright (C) 2008 Christoph Lukes
 * see www.schlu.net for more information
 *
 * PhotoMap Gallery is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the 
 * GNU General Public License for more details.
 */

defined( '_JEXEC' ) or die( 'Restricted access' );

jimport('joomla.application.component.model');

/**
 * PhotoMap Gallery Component Item Model
 *
 * @package Joomla
 * @subpackage PhotoMap Gallery
 * @since		1.0
 */
class photomapgalleryModelGalleryItems extends JModel
{
	/**
	 * Details data in details array
	 *
	 * @var array
	 */
	var $_item = null;
	
	var $_comments = null;
	
	var $_tags = null;

	/**
	 * id
	 *
	 * @var array
	 */
	var $_id = null;
	
	/**
	 * Constructor
	 *
	 * @since 1.0
	 */
	function __construct()
	{
		parent::__construct();

		$id = JRequest::getVar('id', 0, '', 'int');
		$this->setId((int)$id);
	}

	/**
	 * Method to set the touritem id
	 *
	 * @access	public
	 * @param	int	tour ID number
	 */

	function setId($id)
	{
		// Set new tour ID
		$this->_id			= $id;
		$this->_item		= null;
	}

	/**
	 * Overridden get method to get properties from the item
	 *
	 * @access	public
	 * @param	string	$property	The name of the property
	 * @param	mixed	$value		The value of the property to set
	 * @return 	mixed 				The value of the property
	 * @since	1.5
	 */
	function get($property, $default=null)
	{
		if ($this->_loadItem()) {
			if(isset($this->_item->$property)) {
				return $this->_item->$property;
			}
		}
		return $default;
	}
	
	/**
	 * Overridden set method to pass properties on to the item
	 *
	 * @access	public
	 * @param	string	$property	The name of the property
	 * @param	mixed	$value		The value of the property to set
	 * @return	boolean	True on success
	 * @since	1.5
	 */
	function set( $property, $value=null )
	{
		if ($this->_loadItem()) {
			$this->_item->$property = $value;
			return true;
		} else {
			return false;
		}
	}

	/**
	 * Method to get data for the itemview
	 *
	 * @access public
	 * @return array
	 * @since 1.0
	 */
	function &getItem( )
	{
		/*
		* Load the Item data
		*/
		if ($this->_loadItem())
		{
			$user	= & JFactory::getUser();

			// Is the category published?
			if (!$this->_item->catpublished && $this->_item->catid)
			{
				JError::raiseError( 404, JText::_("CATEGORY NOT PUBLISHED") );
			}

			// Do we have access to the category?
			if (($this->_item->cataccess > $user->get('aid')) && $this->_item->catid)
			{
				JError::raiseError( 403, JText::_("ALERTNOTAUTH") );
			}

			//reduce unneeded query
			if ($this->_item->created_by_alias) {
				$this->_item->creator = $this->_item->created_by_alias;
			} else {
				$query = 'SELECT name'
				. ' FROM #__users'
				. ' WHERE id = '. (int) $this->_item->created_by
				;
				$this->_db->setQuery($query);
				$this->_item->creator = $this->_db->loadResult();
			}

			//reduce unneeded query
			if ($this->_item->created_by == $this->_item->modified_by) {
				$this->_item->modifier = $this->_item->creator;
			} else {
				$query = 'SELECT name'
				. ' FROM #__users'
				. ' WHERE id = '. (int) $this->_item->modified_by
				;
				$this->_db->setQuery($query);
				$this->_item->modifier = $this->_db->loadResult();
			}

			if ($this->_item->modified == $this->_db->getNulldate()) {
				$this->_item->modified = null;
			}

			//check session if uservisit already recorded
			$session 	=& JFactory::getSession();
			$hitcheck = false;
			if ($session->has('hit', 'photomapgallery')) {
				$hitcheck 	= $session->get('hit', 0, 'photomapgallery');
				$hitcheck 	= in_array($this->_item->id, $hitcheck);
			}
			if (!$hitcheck) {
				//record hit
				$this->hit();

				$stamp = array();
				$stamp[] = $this->_item->id;
				$session->set('hit', $stamp, 'photomapgallery');
			}
		}
		else
		{
			$user =& JFactory::getUser();
			$item =& JTable::getInstance('g_galleryitems', '');
			if ($user->authorize('com_photomapgallery', 'state'))	{
				$item->state = 1;
			}
			$item->id					= 0;
			$item->author				= null;
			$item->created_by			= $user->get('id');
			$item->text					= '';
			$item->title				= null;
			$item->meta_description		= '';
			$item->meta_keywords		= '';
			$this->_item				= $item;
		}

		return $this->_item;
	}

	/**
	 * Method to load required data
	 *
	 * @access	private
	 * @return	array
	 * @since	1.0
	 */
	function _loadItem()
	{
		if($this->_id == '0') {
			return false;
		}

		if (empty($this->_item))
		{
			$query = 'SELECT i.*, c.access AS cataccess, c.id AS catid, c.title AS catitle, c.published AS catpublished, c.directory,'
			. ' u.username AS author, g.name AS groupname,'
			. ' CASE WHEN CHAR_LENGTH(i.alias) THEN CONCAT_WS(\':\', i.id, i.alias) ELSE i.id END as slug,'
			. ' CASE WHEN CHAR_LENGTH(c.alias) THEN CONCAT_WS(\':\', c.id, c.alias) ELSE c.id END as categoryslug'
			. ' FROM #__g_galleryitems AS i'
			. ' LEFT JOIN #__g_cats_item_relations AS rel ON rel.itemid = i.id'
			. ' LEFT JOIN #__g_categories AS c ON c.id = rel.catid'
			. ' LEFT JOIN #__g_user AS u ON u.userID = c.userid'
			. ' LEFT JOIN #__g_user_groups AS g ON g.id = u.group'
			. ' WHERE i.id = '.$this->_id
			;
			$this->_db->setQuery($query);
			$this->_item = $this->_db->loadObject();
			return (boolean) $this->_item;
		}
		return true;
	}

	function getCategory($id)
	{
		$query = 'SELECT DISTINCT c.title, c.directory'
				. ' FROM #__g_categories AS c'
				. ' LEFT JOIN #__g_cats_item_relations AS rel ON rel.catid = c.id'
				. ' WHERE rel.itemid = '.(int)$id
				;
	
		$this->_db->setQuery( $query );
		$cats = $this->_db->loadObject();

		return $cats;
	}

	function getMainCategory($userid)
	{
		//get categories
		$query = 'SELECT c.*,'
				. ' CASE WHEN CHAR_LENGTH(c.alias) THEN CONCAT_WS(\':\', c.id, c.alias) ELSE c.id END as slug'
				. ' FROM #__g_categories AS c'
				. ' WHERE c.userid = '.$userid
				. ' AND c.parent_id = 0'
				. ' AND c.published = 1'
				;

		$this->_db->setQuery($query);
		$maincategory = $this->_db->loadObject();

		return $maincategory;
	}
	
	function removeitem($itemid)
	{	
		$category	= $this->getCategory($itemid);

		$query = 'SELECT filename FROM #__g_galleryitems WHERE id = '.$itemid;
		$this->_db->setQuery($query);
		$fileObject = $this->_db->loadObject();

		if (file_exists(GALLERY_IMAGES_ORIGINAL.DS.$category->directory.DS.$fileObject->filename)) {
			if (!JFile::delete(GALLERY_IMAGES_ORIGINAL.DS.$category->directory.DS.$fileObject->filename))
				JError::raiseNotice(500, JText::_('ERROR DELETE ORIGINAL'));
			else
				JError::raiseNotice(500, JText::_('DELETE ORIGINAL'));
		}
		else {
			JError::raiseNotice(500, JText::_('CAN NOT FIND ORIGINAL'));
			return false;
		}
		
		if (file_exists(GALLERY_IMAGES_ALBUM_URL.$category->directory.DS.$fileObject->filename)) {
			if (!JFile::delete(GALLERY_IMAGES_ALBUM_URL.$category->directory.DS.$fileObject->filename))
				JError::raiseNotice(500, JText::_('ERROR DELETE ALBUM'));
			else
				JError::raiseNotice(500, JText::_('DELETE ALBUM'));
		}
		else {
			JError::raiseNotice(500, JText::_('CAN NOT FIND ALBUM'));
			return false;
		}
		
		if (file_exists(GALLERY_IMAGES_RESIZED_URL.$category->directory.DS.$fileObject->filename)) {
			if (!JFile::delete(GALLERY_IMAGES_RESIZED_URL.$category->directory.DS.$fileObject->filename))
				JError::raiseNotice(500, JText::_('ERROR DELETE RESIZE'));
			else
				JError::raiseNotice(500, JText::_('DELETE RESIZE'));
		}
		else {
			JError::raiseNotice(500, JText::_('CAN NOT FIND RESIZE'));
			return false;
		}
		
		if (file_exists(GALLERY_IMAGES_THUMBNAIL_URL.$category->directory.DS.$fileObject->filename)) {
			if (!JFile::delete(GALLERY_IMAGES_THUMBNAIL_URL.$category->directory.DS.$fileObject->filename))
				JError::raiseNotice(500, JText::_('ERROR DELETE THUMB'));
			else
				JError::raiseNotice(500, JText::_('DELETE THUMB'));
		}
		else {
			JError::raiseNotice(500, JText::_('CAN NOT FIND THUMB'));
			return false;
		}
		
		//remove assigned category references
		$query = 'DELETE FROM #__g_cats_item_relations'
				.' WHERE itemid = '. $itemid
				;
		$this->_db->setQuery($query);

		if(!$this->_db->query()) {
			$this->setError($this->_db->getErrorMsg());
			return false;
		}
		
		$query = 'DELETE FROM #__g_galleryitems'
				. ' WHERE id = '. $itemid
				;

		$this->_db->setQuery( $query );
		
		if(!$this->_db->query()) {
			$this->setError($this->_db->getErrorMsg());
			JError::raiseNotice(500, JText::_('QUERY ERROR'));
			return false;
		}

		return true;
	}
	
	function getTags()
	{
		$query = 'SELECT DISTINCT t.name,'
				. ' CASE WHEN CHAR_LENGTH(t.alias) THEN CONCAT_WS(\':\', t.id, t.alias) ELSE t.id END as slug'
				. ' FROM #__g_tags AS t'
				. ' LEFT JOIN #__g_tags_item_relations AS i ON i.tid = t.id'
				. ' WHERE i.itemid = ' . (int) $this->_id
				. ' AND t.published = 1'
				. ' ORDER BY t.name'
				;

		$this->_db->setQuery( $query );
		$this->_tags = $this->_db->loadObjectList();

		return $this->_tags;
	}
	
	function getAlltags($userid)
	{
		$user =& JFactory::getUser();
		
		$query = 'SELECT *'
				. ' FROM #__g_tags'
				. ' WHERE userid = '.$userid
				. ' ORDER BY name'
				;
		$this->_db->setQuery($query);
		$tags = $this->_db->loadObjectlist();
		return $tags;
	}

	function getCountTags($userid, $min)
	{		
		$query = 'SELECT DISTINCT t.name, t.id, count( rel.tid ) AS no,'
				. ' CASE WHEN CHAR_LENGTH(t.alias) THEN CONCAT_WS(\':\', t.id, t.alias) ELSE t.id END as slug'
				. ' FROM #__g_tags AS t'
				. ' LEFT JOIN #__g_tags_item_relations AS rel ON rel.tid = t.id'
				. ' WHERE t.userid = '.$userid
				. ' AND t.published = 1'
				. ' GROUP BY t.id'
				. ' HAVING no >= '. $min
				;
				
		$this->_db->setQuery($query);
		$rows = $this->_db->loadObjectlist();
		
		return $rows;
	}
	
	function getLimitTags($userid, $number)
	{		
		$query = 'SELECT DISTINCT t.name, t.id, count( rel.tid ) AS no,'
				. ' CASE WHEN CHAR_LENGTH(t.alias) THEN CONCAT_WS(\':\', t.id, t.alias) ELSE t.id END as slug'
				. ' FROM #__g_tags AS t'
				. ' LEFT JOIN #__g_tags_item_relations AS rel ON rel.tid = t.id'
				. ' WHERE t.userid = '.$userid
				. ' AND t.published = 1'
				. ' GROUP BY t.id'
				. ' HAVING no >= 1'
				;
		$this->_db->setQuery($query,0,$number);		
		$rows = $this->_db->loadObjectlist();
		
		return $rows;
	}
	
	function getUsedtags()
	{
		$query = 'SELECT tid'
				. ' FROM #__g_tags_item_relations'
				. ' WHERE itemid = ' . (int)$this->_id
				;
		$this->_db->setQuery($query);
		$used = $this->_db->loadResultArray();
		return $used;
	}
	/**
	 * Method to get the categories
	 *
	 * @access	public
	 * @return	object
	 * @since	1.0
	 */
	function getCategories()
	{
		$query = 'SELECT DISTINCT c.id, c.title,'
		. ' CASE WHEN CHAR_LENGTH(c.alias) THEN CONCAT_WS(\':\', c.id, c.alias) ELSE c.id END as slug'
		. ' FROM #__g_categories AS c'
		. ' LEFT JOIN #__g_cats_item_relations AS rel ON rel.catid = c.id'
		. ' WHERE rel.itemid = '.$this->_id
		;

		$this->_db->setQuery( $query );

		$this->_cats = $this->_db->loadObjectList();

		return $this->_cats;
	}

	/**
	 * Method to increment the hit counter for the item
	 *
	 * @access	public
	 * @return	boolean	True on success
	 * @since	1.0
	 */
	function hit()
	{
		if ($this->_id)
		{
			$item = & JTable::getInstance('g_galleryitems', '');
			$item->hit($this->_id);
			return true;
		}
		return false;
	}


	/**
	 * Tests if item is checked out
	 *
	 * @access	public
	 * @param	int	A user id
	 * @return	boolean	True if checked out
	 * @since	1.0
	 */
	function isCheckedOut( $uid=0 )
	{
		if ($this->_loadItem())
		{
			if ($uid) {
				return ($this->_item->checked_out && $this->_item->checked_out != $uid);
			} else {
				return $this->_item->checked_out;
			}
		} elseif ($this->_id < 1) {
			return false;
		} else {
			JError::raiseWarning( 0, 'Unable to Load Data');
			return false;
		}
	}

	/**
	 * Method to checkin/unlock the item
	 *
	 * @access	public
	 * @return	boolean	True on success
	 * @since	1.0
	 */
	function checkin()
	{
		if ($this->_id)
		{
			$item = & JTable::getInstance('g_galleryitems', '');
			return $item->checkin($this->_id);
		}
		return false;
	}

	/**
	 * Method to checkout/lock the item
	 *
	 * @access	public
	 * @param	int	$uid	User ID of the user checking the item out
	 * @return	boolean	True on success
	 * @since	1.0
	 */
	function checkout($uid = null)
	{
		if ($this->_id)
		{
			// Make sure we have a user id to checkout the item with
			if (is_null($uid)) {
				$user	=& JFactory::getUser();
				$uid	= $user->get('id');
			}
			// Lets get to it and checkout the thing...
			$item = & JTable::getInstance('g_galleryitems', '');
			return $item->checkout($uid, $this->_id);
		}
		return false;
	}
	
	/**
	 * Method to store the item
	 *
	 * @access	public
	 * @since	1.0
	 */
	function store($data)
	{
		$item  		=& JTable::getInstance('g_galleryitems', '');
		$tags 		= JRequest::getVar( 'tag', array(), 'post', 'array');
		$cats 		= JRequest::getVar( 'cid', array(), 'post', 'array');
		$user     	=& JFactory::getUser();
	
		// Bind the form fields to the table
		if (!$item->bind($data)) {
			$this->setError($this->_db->getErrorMsg());
			return false;
		}
	
		// sanitise id field
		$item->id = (int) $item->id;
		
		$item->user_id = (int) $user->id;

		$isNew = ($item->id < 1);

		if ($isNew)
		{
			$item->created 		= gmdate('Y-m-d H:i:s');
			$item->created_by 	= $user->get('id');
			
			$item->ordering = $item->getNextOrder();
		}
		else
		{
			$item->modified 	= gmdate('Y-m-d H:i:s');
			$item->modified_by 	= $user->get('id');

			$query = 'SELECT hits, rate, rate_sum, created, created_by, version' .
			' FROM #__g_galleryitems' .
			' WHERE id = '.(int) $item->id;

			$this->_db->setQuery($query);
			$result = $this->_db->loadObjectList();

			$item->rate_sum = $result->rate_sum;
			$item->rate = $result->rate;
			$item->hits = $result->hits;
			
			$item->created = $result->created;
			$item->created_by = $result->created_by;
			
			$item->version = $result->version;
			$item->version++;

//			if (!$user->authorize('com_photomapgallery', 'state'))	{
//				$item->state = $result->state;
//			}
		}
/*
		// Publishing state hardening for Authors
		if (!$user->authorize('com_photomapgallery', 'state'))
		{
			if ($isNew)
			{
				// For new touritems
				$item->state = -2;
			}
			else
			{
				$query = 'SELECT published' .
				' FROM #__g_galleryitems' .
				' WHERE id = '.(int) $item->id;

				$this->_db->setQuery($query);
				$result = $this->_db->loadResult();

				$item->state = $result;
			}
		}
	*/	

		// Make sure the data is valid
		if (!$item->check()) {
			$this->setError($item->getError());
			return false;
		}

		// Store the article table to the database
		if (!$item->store()) {
			$this->setError($this->_db->getErrorMsg());
			return false;
		}

		if ($isNew)
		{
			$this->_id = $item->_db->insertId();
		}

		//store tags
		$query = 'DELETE FROM #__g_tags_item_relations WHERE itemid = '.$item->id;
		$this->_db->setQuery($query);
		$this->_db->query();

		foreach($tags as $tag)
		{
			$query = 'INSERT INTO #__g_tags_item_relations (`tid`, `itemid`) VALUES(' . $tag . ',' . $item->id . ')';
			$this->_db->setQuery($query);
			$this->_db->query();
		}
		
		//store cat relation
		$query = 'DELETE FROM #__g_cats_item_relations WHERE itemid = '.$item->id;
		$this->_db->setQuery($query);
		$this->_db->query();

		foreach($cats as $cat)
		{
			$query = 'INSERT INTO #__g_cats_item_relations (`catid`, `itemid`) VALUES(' . $cat . ',' . $item->id . ')';
			$this->_db->setQuery($query);
			$this->_db->query();
		}

		$this->_item	=& $item;

		return $this->_item->id;
	}

	/**
	 * Method to store a vote
	 *
	 * @access	public
	 * @return	boolean	True on success
	 * @since	1.0
	 */
	function storevote($id, $vote)
	{
		if ($vote == 1) {
			$target = 'rate_sum';
		} elseif ($vote == 0) {
			$target = 'miratenus';
		} else {
			return false;
		}

		$query = 'UPDATE #__g_galleryitems'
		.' SET '.$target.' = ( '.$target.' + 1 )'
		.' WHERE id = '.(int)$id
		;
		$this->_db->setQuery($query);
		$this->_db->query();

		return true;
	}

	function storetag($data)
	{
		$row  =& $this->getTable('g_tags', '');

		// bind it to the table
		if (!$row->bind($data)) {
			JError::raiseError(500, $this->_db->getErrorMsg() );
			return false;
		}

		// Make sure the data is valid
		if (!$row->check()) {
			$this->setError($row->getError());
			return false;
		}

		// Store it in the db
		if (!$row->store()) {
			JError::raiseError(500, $this->_db->getErrorMsg() );
			return false;
		}

		return $row->id;
	}
	
	function addtag($name)
	{
		$user     	=& JFactory::getUser();
		
		$obj = new stdClass();
		$obj->name	 	= $name;
		$obj->userid	= $user->id;
		$obj->published	= 1;

		$this->storetag($obj);

		//	$this->_db->insertObject('#__g_tags', $obj);

		return true;
	}
	
	/**
	 * Method to get the categories an item is assigned to
	 *
	 * @access	public
	 * @return	boolean	True on success
	 * @since	1.0
	 */
	function getCatsselected()
	{
		$query = 'SELECT DISTINCT catid FROM #__g_cats_item_relations WHERE itemid = ' . (int)$this->_id;
		$this->_db->setQuery($query);
		$used = $this->_db->loadResultArray();
		return $used;
	}

	function storecomment($data)
	{
		$row  =& $this->getTable('g_testimonial', '');

		// bind it to the table
		if (!$row->bind($data)) {
			JError::raiseError(500, $this->_db->getErrorMsg() );
			return false;
		}

		// Make sure the data is valid
		if (!$row->check()) {
			$this->setError($row->getError());
			return false;
		}

		// Store it in the db
		if (!$row->store()) {
			JError::raiseError(500, $this->_db->getErrorMsg() );
			return false;
		}

		return $row->id;
	}
	
	function addcomment($name)
	{
		$obj = new stdClass();
		$obj->name	 	= $name;
		$obj->published	= 1;

		$this->storecomment($obj);

		return true;
	}
	
	function getFeatured()
	{
		$user 		= &JFactory::getUser();
		$gid		= (int) $user->get('aid');
		$limit 		= JRequest::getVar('limit', 10);

		$query = 'SELECT DISTINCT i.*, c.title AS cattitle,'
		. ' CASE WHEN CHAR_LENGTH(i.alias) THEN CONCAT_WS(\':\', i.id, i.alias) ELSE i.id END as slug,'
		. ' CASE WHEN CHAR_LENGTH(c.alias) THEN CONCAT_WS(\':\', c.id, c.alias) ELSE c.id END as catslug'
		. ' FROM #__g_galleryitems AS i'
		. ' LEFT JOIN #__g_cats_item_relations AS rel ON rel.itemid = i.id'
		. ' LEFT JOIN #__g_categories AS c ON c.id = rel.catid'
		. ' WHERE c.published = 1'
		. ' AND c.access <= '.$gid
		. ' AND i.featured = 1'
		. ' AND i.state IN (1, -4)'
		. ' LIMIT '. $limit
		;
		
		$this->_db->setQuery($query);
		$result = $this->_db->loadObjectList();

		return $result;
	}

	function getRandom($number)
	{
		$user 		= &JFactory::getUser();
		$gid		= (int) $user->get('aid');

		$query = 'SELECT DISTINCT  i.id, i.user_id, i.title, i.filename, i.imagewidth, i.imageheight, i.hits, i.created, c.title AS cattitle, c.directory,'
				. ' CASE WHEN CHAR_LENGTH(i.alias) THEN CONCAT_WS(\':\', i.id, i.alias) ELSE i.id END as slug,'
				. ' CASE WHEN CHAR_LENGTH(c.alias) THEN CONCAT_WS(\':\', c.id, c.alias) ELSE c.id END as catslug'
				. ' FROM #__g_galleryitems AS i'
				. ' LEFT JOIN #__g_cats_item_relations AS rel ON rel.itemid = i.id'
				. ' LEFT JOIN #__g_categories AS c ON c.id = rel.catid'
				. ' WHERE c.published = 1'
				. ' AND c.access <= '.$gid
				. ' AND i.published = 1'
				. ' ORDER BY RAND()'
				. ' LIMIT '. $number
				;
		
		$this->_db->setQuery($query);
		$result = $this->_db->loadObjectList();

		return $result;
	}
	
	/**
	 * Method to change the state of an item
	 *
	 * @access	public
	 * @return	boolean	True on success
	 * @since	1.0
	 */
	function setitemstate($id, $state = 1)
	{
		$user 	=& JFactory::getUser();
		
		if ( $id )
		{
			$query = 'UPDATE #__g_galleryitems'
				. ' SET published = ' . (int)$state
				. ' WHERE id = '.(int)$id
				. ' AND ( checked_out = 0 OR ( checked_out = ' . (int) $user->get('id'). ' ) )'
			;
			$this->_db->setQuery( $query );
			if (!$this->_db->query()) {
				$this->setError($this->_db->getErrorMsg());
				return false;
			}
		}
		return true;
	}
	
	function getGalleryItem( $id )
	{
		// Where conditions
		$wheres[] = 'gallery.id = ' . (int) $id;
					
		$query	= 	'SELECT gallery.*, user.name AS postedby
					FROM #__g_galleryitems AS gallery LEFT JOIN #__users AS user ON gallery.user_id = user.id
					WHERE gallery.published = "1" AND '. implode( ' AND ', $wheres );
 		$gallerylist = $this->_getList( $query );
		return @$gallerylist[0];
	}
	
	function getMicroNavItem($itemid, $catid, $ordering, $hits, $type, $limit){
		//initialize some vars
		$user		= & JFactory::getUser();
	
		if ($type == 1) {
			$wherel = ' WHERE i.hits > '.$hits;
			$wherel .= ' AND i.published = 1';
			$orderbyl 	= ' ORDER BY i.hits ASC';
			
			$wherer = ' WHERE i.hits < '.$hits;
			$wherer .= ' AND i.published = 1';
			$orderbyr 	= ' ORDER BY i.hits DESC';
		}
		else if ($type == 2) {
			$wherel = ' WHERE i.id >= '.$itemid;
			$wherel .= ' AND i.published = 1';
			$orderbyl 	= ' ORDER BY i.id ASC';
			
			$wherer = ' WHERE i.id < '.$itemid;
			$wherer .= ' AND i.published = 1';
			$orderbyr 	= ' ORDER BY i.id DESC';
		}
		if (empty($type)) {
			$wherel = ' WHERE c.id = ' . $catid;
			$wherel .= ' AND i.ordering <= '.$ordering;
			$wherel .= ' AND i.published = 1';
			$orderbyl 	= ' ORDER BY i.ordering DESC';
			
			$wherer = ' WHERE c.id = ' . $catid;
			$wherer .= ' AND i.ordering > '.$ordering;
			$wherer .= ' AND i.published = 1';
			$orderbyr 	= ' ORDER BY i.ordering ASC';
		}
				
		$query = 'SELECT count(i.id)'
				. ' FROM #__g_galleryitems AS i'
				. ' LEFT JOIN #__g_cats_item_relations AS rel ON rel.itemid = i.id'
				. ' LEFT JOIN #__g_categories AS c ON c.id = rel.catid'
				. $wherel
				. $orderbyl
				;
				
		$this->_db->setQuery($query);
		$leftcount = $this->_db->loadResult();

		$query = 'SELECT count(i.id)'
				. ' FROM #__g_galleryitems AS i'
				. ' LEFT JOIN #__g_cats_item_relations AS rel ON rel.itemid = i.id'
				. ' LEFT JOIN #__g_categories AS c ON c.id = rel.catid'
				. $wherer
				. $orderbyr
				;
				
		$this->_db->setQuery($query);
		$rightcount = $this->_db->loadResult();
		
		if ($leftcount < $limit/2)
			$rightlimit = $limit/2 + ($limit/2 - $leftcount);
		else
			$rightlimit = $limit/2;
			
		if ($rightcount < $limit/2)
			$leftlimit = $limit/2 + ($limit/2 - $rightcount);
		else
			$leftlimit = $limit/2;
						
		$query = 'SELECT i.*, c.directory, c.title AS cattitle, g.name AS groupname,'
				. ' CASE WHEN CHAR_LENGTH(i.alias) THEN CONCAT_WS(\':\', i.id, i.alias) ELSE i.id END as slug'
				. ' FROM #__g_galleryitems AS i'
				. ' LEFT JOIN #__g_cats_item_relations AS rel ON rel.itemid = i.id'
				. ' LEFT JOIN #__g_categories AS c ON c.id = rel.catid'
				. ' LEFT JOIN #__g_user AS u ON u.userID = c.userid'
				. ' LEFT JOIN #__g_user_groups AS g ON g.id = u.group'
				. $wherel
				. $orderbyl
				;
				
		$this->_db->setQuery($query,0,$leftlimit);
		$left = $this->_db->loadObjectList();
		krsort($left);

		$query = 'SELECT i.*, c.directory, c.title AS cattitle, g.name AS groupname,'
				. ' CASE WHEN CHAR_LENGTH(i.alias) THEN CONCAT_WS(\':\', i.id, i.alias) ELSE i.id END as slug'
				. ' FROM #__g_galleryitems AS i'
				. ' LEFT JOIN #__g_cats_item_relations AS rel ON rel.itemid = i.id'
				. ' LEFT JOIN #__g_categories AS c ON c.id = rel.catid'
				. ' LEFT JOIN #__g_user AS u ON u.userID = c.userid'
				. ' LEFT JOIN #__g_user_groups AS g ON g.id = u.group'
				. $wherer
				. $orderbyr
				;
				
		$this->_db->setQuery($query,0,$rightlimit);
		$right = $this->_db->loadObjectList();

		$row = array_merge($left, $right);

		return $row;
	}
	
	function getNextItem($itemid, $catid, $ordering, $hits, $type){
		//initialize some vars
		$user		= & JFactory::getUser();
		$gid		= (int) $user->get('aid');
		
		$where 		= ' WHERE i.id != '.$itemid;
		$where 	   .= ' AND i.published = 1';
		if ($type == 1) {	
			$where 	   .= ' AND i.hits < '.$hits;
			$orderby	= ' ORDER BY i.hits DESC';
		}
		else if ($type == 2) {
			$where 	   .= ' AND i.id < '.$itemid;
			$orderby	= ' ORDER BY i.id DESC';
		}
		if (empty($type)) {
			$where 	   .= ' AND c.id = '.$catid;
			$where 	   .= ' AND i.ordering > '.$ordering;
			$orderby	= ' ORDER BY i.ordering ASC';
		}
		$limit		= ' LIMIT 1';
		
		$query = 'SELECT i.*, c.title AS cattitle,'
				. ' CASE WHEN CHAR_LENGTH(i.alias) THEN CONCAT_WS(\':\', i.id, i.alias) ELSE i.id END as slug'
				. ' FROM #__g_galleryitems AS i'
				. ' LEFT JOIN #__g_cats_item_relations AS rel ON rel.itemid = i.id'
				. ' LEFT JOIN #__g_categories AS c ON c.id = rel.catid'
				. $where
				. $orderby
				. $limit
				;

		$this->_db->setQuery($query);
		$row = $this->_db->loadObject();

		return $row;
	}
	
	function getPreviousItem($itemid, $catid, $ordering, $hits, $type){
		//initialize some vars
		$user		= & JFactory::getUser();
		$gid		= (int) $user->get('aid');

		$where 		= ' WHERE i.id != '.$itemid;
		$where 	   .= ' AND i.published = 1';
		if ($type == 1) {	
			$where 	   .= ' AND i.hits > '.$hits;
			$orderby	= ' ORDER BY i.hits ASC';
		}
		else if ($type == 2) {
			$where 	   .= ' AND i.id > '.$itemid;
			$orderby	= ' ORDER BY i.id ASC';
		}
		if (empty($type)) {
			$where 	   .= ' AND c.id = '.$catid;
			$where 	   .= ' AND i.ordering < '.$ordering;
			$orderby	= ' ORDER BY i.ordering DESC';
		}
		$limit		= ' LIMIT 1';
		
		$query = 'SELECT i.id, i.user_id, i.filename, c.title AS cattitle,'
				. ' CASE WHEN CHAR_LENGTH(i.alias) THEN CONCAT_WS(\':\', i.id, i.alias) ELSE i.id END as slug'
				. ' FROM #__g_galleryitems AS i'
				. ' LEFT JOIN #__g_cats_item_relations AS rel ON rel.itemid = i.id'
				. ' LEFT JOIN #__g_categories AS c ON c.id = rel.catid'
				. $where
				. $orderby
				. $limit
				;
			
		$this->_db->setQuery($query);
		$row = $this->_db->loadObject();

		return $row;
	}
	
	function getFirstItem($catid, $type){

		$user		= & JFactory::getUser();
		$gid		= (int) $user->get('aid');

		$where 		= ' WHERE i.published = 1';
		if ($type == 1) {			
			$orderby	= ' ORDER BY i.hits DESC';
		}
		else if ($type == 2) {
			$orderby	= ' ORDER BY i.id DESC';
		}
		if (empty($type)) {
			$where 	   .= ' AND c.id = '.$catid;
			$orderby	= ' ORDER BY i.ordering ASC';
		}
		$limit		= ' LIMIT 1';
		
		$query = 'SELECT i.id, c.title AS cattitle,'
				. ' CASE WHEN CHAR_LENGTH(i.alias) THEN CONCAT_WS(\':\', i.id, i.alias) ELSE i.id END as slug'
				. ' FROM #__g_galleryitems AS i'
				. ' LEFT JOIN #__g_cats_item_relations AS rel ON rel.itemid = i.id'
				. ' LEFT JOIN #__g_categories AS c ON c.id = rel.catid'
				. $where
				. $orderby
				. $limit
				;

		$this->_db->setQuery($query);
		$row = $this->_db->loadObject();

		return $row;
	}
	
	function getLastItem($catid, $type){

		$user		= & JFactory::getUser();
		$gid		= (int) $user->get('aid');

		$where 		= ' WHERE i.published = 1';
		if ($type == 1) {			
			$orderby	= ' ORDER BY i.hits ASC';
		}
		else if ($type == 2) {
			$orderby	= ' ORDER BY i.id ASC';
		}
		if (empty($type)) {
			$where 	   .= ' AND c.id = '.$catid;
			$orderby	= ' ORDER BY i.ordering DESC';
		}
		$limit		= ' LIMIT 1';
		
		$query = 'SELECT i.id, c.title AS cattitle,'
				. ' CASE WHEN CHAR_LENGTH(i.alias) THEN CONCAT_WS(\':\', i.id, i.alias) ELSE i.id END as slug'
				. ' FROM #__g_galleryitems AS i'
				. ' LEFT JOIN #__g_cats_item_relations AS rel ON rel.itemid = i.id'
				. ' LEFT JOIN #__g_categories AS c ON c.id = rel.catid'
				. $where
				. $orderby
				. $limit
				;

		$this->_db->setQuery($query);
		$row = $this->_db->loadObject();

		return $row;
	}

	function getFavourites()
	{
		$query = 'SELECT COUNT(id) AS favs FROM #__g_favourites WHERE itemid = '.(int)$this->_id;
		$this->_db->setQuery($query);
		$favs = $this->_db->loadResult();
		return $favs;
	}
	
	function getFavoured()
	{
		$user = JFactory::getUser();

		$query = 'SELECT COUNT(id) AS fav FROM #__g_favourites WHERE itemid = '.(int)$this->_id.' AND userid= '.(int)$user->id;
		$this->_db->setQuery($query);
		$fav = $this->_db->loadResult();
		return $fav;
	}
	
	function removefav($itemid)
	{
		$user = JFactory::getUser();

		$query = 'DELETE FROM #__g_favourites WHERE itemid = '.$itemid.' AND userid = '.(int)$user->id;
		$this->_db->setQuery($query);
		$remfav = $this->_db->query();
		return $remfav;
	}
	
	function addfav($itemid)
	{
		$user = JFactory::getUser();

		$obj = new stdClass();
		$obj->itemid 	= $itemid;
		$obj->userid	= $user->id;

		$addfav = $this->_db->insertObject('#__g_favourites', $obj);
		return $addfav;
	}
	
	function updateExif($exif, $itemid)
	{
		$query = 'UPDATE #__g_galleryitems SET `exif` = ' . $this->_db->quote($exif). ' WHERE `id` = '.$itemid;
		$this->_db->setQuery($query);
		if(!$this->_db->query()) {
			$this->setError($this->_db->getErrorMsg());
			return false;
		}

		return $true;
	}
}
?>