<?php
/**
 * @version 1.1 beta $Id: tags.php 2009-12-28 $
 * @package Joomla
 * @subpackage PhotoMap Gallery
 * @copyright (C) 2009 - 2010 Oh-Taek Im - www.photoindochina.com
 * @license GNU/GPL v2
 * 
 * PhotoMap Gallery is a derivative work of the excellent QuickFAQ component
 * @copyright (C) 2008 Christoph Lukes
 * see www.schlu.net for more information
 *
 * PhotoMap Gallery is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the 
 * GNU General Public License for more details.
 */

// no direct access
defined( '_JEXEC' ) or die( 'Restricted access' );

jimport('joomla.application.component.model');

/**
 * PhotoMap Gallery Component Model
 *
 * @package Joomla
 * @subpackage PhotoMap Gallery
 * @since		1.0
 */
class photomapgalleryModelTags extends JModel
{
	/**
	 * Data
	 *
	 * @var mixed
	 */
	var $_data = null;
	
	/**
	 * Tag
	 *
	 * @var mixed
	 */
	var $_tag = null;
	
	/**
	 * Items total
	 *
	 * @var integer
	 */
	var $_total = null;

	/**
	 * Constructor
	 *
	 * @since 1.0
	 */
	function __construct()
	{
		parent::__construct();
		
		global $mainframe;

		// Get the paramaters of the active menu item
		$params = & $mainframe->getParams('com_photomapgallery');

		//get the number of events from database
		$limit			= JRequest::getInt('limit');//JRequest::getInt('limit', $params->get('limit'));
		$limitstart		= JRequest::getInt('limitstart');
		$id				= JRequest::getInt('id', 0);
		
		$this->setId((int)$id);

		$this->setState('limit', $limit);
		$this->setState('limitstart', $limitstart);
		
		// Get the filter request variables
		$this->setState('filter_order', JRequest::getCmd('filter_order', 'i.title'));
		$this->setState('filter_order_dir', JRequest::getCmd('filter_order_Dir', 'ASC'));
	}
	
	/**
	 * Method to set the tag id
	 *
	 * @access	public
	 * @param	int	tag ID number
	 */
	function setId($id)
	{
		// Set new category ID and wipe data
		$this->_id			= $id;
		$this->_data		= null;
	}

	/**
	 * Method to get Data
	 *
	 * @access public
	 * @return object
	 */
	function getData()
	{
		// Lets load the content if it doesn't already exist
		if (empty($this->_data))
		{		
			$query = $this->_buildQuery();
			$this->_data = $this->_getList( $query, $this->getState('limitstart'), $this->getState('limit') );
		}
		
		return $this->_data;
	}
	
	/**
	 * Total nr of Items
	 *
	 * @access public
	 * @return integer
	 */
	function getTotal()
	{
		// Lets load the total nr if it doesn't already exist
		if (empty($this->_total))
		{
			$query = $this->_buildQuery();
			$this->_total = $this->_getListCount($query);
		}

		return $this->_total;
	}
	
	/**
	 * Method to build the query
	 *
	 * @access public
	 * @return string
	 */
	function _buildQuery()
	{   	
        // Get the WHERE and ORDER BY clauses for the query
		$where		= $this->_buildItemWhere();
		$orderby	= $this->_buildItemOrderBy();

		$query = 'SELECT i.id, i.title, i.filename, i.user_id, c.title AS cattitle, c.directory, u.gallerytitle, u.name,'
				. ' CASE WHEN CHAR_LENGTH(i.alias) THEN CONCAT_WS(\':\', i.id, i.alias) ELSE i.id END as slug'
				. ' FROM #__g_galleryitems AS i'
				. ' INNER JOIN #__g_tags_item_relations AS t ON t.itemid = i.id'
				. ' LEFT JOIN #__g_cats_item_relations AS rel ON rel.itemid = i.id'
				. ' LEFT JOIN #__g_categories AS c ON c.id = rel.catid'
				. ' LEFT JOIN #__g_user AS u ON u.userID = i.user_id'
				. $where
				. ' GROUP BY i.id'
				. $orderby
				;

		return $query;
	}

	/**
	 * Build the order clause
	 *
	 * @access private
	 * @return string
	 */
	function _buildItemOrderBy()
	{	
		$filter_order		= $this->getState('filter_order');
		$filter_order_dir	= $this->getState('filter_order_dir');

		$orderby 	= ' ORDER BY '.$filter_order.' '.$filter_order_dir.', i.title';

		return $orderby;
	}
	
	/**
	 * Method to build the WHERE clause
	 *
	 * @access private
	 * @return string
	 */
	function _buildItemWhere( )
	{
		global $mainframe;

		$user		= & JFactory::getUser();
		$gid		= (int) $user->get('aid');
		$params 	= & $mainframe->getParams('com_photomapgallery');
		// shortcode of the site active language (joomfish)
//		$lang 		= JRequest::getWord('lang', '' );
//		$filtertag  = $params->get('filtertag', 0);

		// First thing we need to do is to select only the requested items
//		$where = ' WHERE t.tid = '.$this->_id;
/*		
		// Filter the category view with the active active language
		if (FLEXI_FISH && $filtertag) {
			$where .= ' AND ie.language LIKE ' . $this->_db->Quote( $lang .'%' );
		}

		$states = '1, -5';
		if ($user->authorize('com_photomapgallery', 'state')) {
			$states .= ', 0 , -3, -4';
		}
		$where .= ' AND i.state IN ('.$states.')';*/
		$where .= ' WHERE i.published = 1';
		$where .= ' AND t.tid = '.$this->_id;
//		$where .= ' AND i.access <= '.$gid;
		
		// Second is to only select items assigned to category the user has access to
//		$where .= ' AND c.access <= '.$gid;

		/*
		 * If we have a filter, and this is enabled... lets tack the AND clause
		 * for the filter onto the WHERE clause of the item query.
		 */
/*		if ($params->get('use_search'))
		{
			$filter 		= JRequest::getString('filter', '', 'request');

			if ($filter)
			{
				// clean filter variables
				// $filter			= $this->_db->getEscaped( trim(JString::strtolower( $filter ) ) );
				// $where .= ' AND LOWER( i.title ) LIKE '.$this->_db->Quote( '%'.$this->_db->getEscaped( $filter, true ).'%', false );
//				$where .= ' AND MATCH (ie.search_index) AGAINST ('.$this->_db->Quote( $this->_db->getEscaped( $filter, true ), false ).' IN BOOLEAN MODE)';
			}
		}*/
		return $where;
	}
	
	/**
	 * Method to load the Tag data
	 *
	 * @access public
	 * @return object
	 */
	function getTag()
	{
		//get categories
		$query = 'SELECT t.name, t.id,'
				. ' CASE WHEN CHAR_LENGTH(t.alias) THEN CONCAT_WS(\':\', t.id, t.alias) ELSE t.id END as slug'
				. ' FROM #__g_tags AS t'
				. ' WHERE t.id = '.$this->_id
				. ' AND t.published = 1'
				;

		$this->_db->setQuery($query);
        $this->_tag = $this->_db->loadObject();
        
		return $this->_tag;
	}
	
	function getAlltags($userid)
	{
		$user =& JFactory::getUser();
		
		$query = 'SELECT t.*'
				. ' FROM #__g_tags AS t'
				. ' WHERE t.userid = '.$userid
				. ' AND t.published = 1'
				. ' ORDER BY t.name'
				;
		$this->_db->setQuery($query);
		$tags = $this->_db->loadObjectlist();
		return $tags;
	}
	
	function getCountTags($userid, $min)
	{		
		$query = 'SELECT DISTINCT t.name, t.id, count( rel.tid ) AS no,'
				. ' CASE WHEN CHAR_LENGTH(t.alias) THEN CONCAT_WS(\':\', t.id, t.alias) ELSE t.id END as slug'
				. ' FROM #__g_tags AS t'
				. ' LEFT JOIN #__g_tags_item_relations AS rel ON rel.tid = t.id'
				. ' WHERE t.userid = '.$userid
				. ' AND t.published = 1'
				. ' GROUP BY t.id'
				. ' HAVING no >= '. $min
				. ' ORDER BY t.name'
				;
				
		$this->_db->setQuery($query);
		$rows = $this->_db->loadObjectlist();
		
		return $rows;
	}
	
	function getLimitTags($userid, $number)
	{		
		$query = 'SELECT DISTINCT t.name, t.id, count( rel.tid ) AS no,'
				. ' CASE WHEN CHAR_LENGTH(t.alias) THEN CONCAT_WS(\':\', t.id, t.alias) ELSE t.id END as slug'
				. ' FROM #__g_tags AS t'
				. ' LEFT JOIN #__g_tags_item_relations AS rel ON rel.tid = t.id'
				. ' WHERE t.userid = '.$userid
				. ' AND t.published = 1'
				. ' GROUP BY t.id'
				. ' HAVING no >= 1'
				. ' ORDER BY t.name'
				;
				
		$this->_db->setQuery($query,0,$number);
		$rows = $this->_db->loadObjectlist();
		
		return $rows;
	}
	
	function getAvatar($userid) {

		$query = 'SELECT u.*, g.name AS groupname'
				. ' FROM #__g_user AS u'
				. ' LEFT JOIN #__g_user_groups AS g ON g.id = u.group'
				. ' WHERE u.userID = '.$userid
				;
		$this->_db->setQuery($query);
		$row = $this->_db->loadObject();
			
		return $row;
	}
	
	function getMainCategory($userid)
	{
		//get categories
		$query = 'SELECT c.*,'
				. ' CASE WHEN CHAR_LENGTH(c.alias) THEN CONCAT_WS(\':\', c.id, c.alias) ELSE c.id END as slug'
				. ' FROM #__g_categories AS c'
				. ' WHERE c.userid = '.$userid
				. ' AND c.parent_id = 0'
				. ' AND c.published = 1'
				;

		$this->_db->setQuery($query);
		$maincategory = $this->_db->loadObject();

		return $maincategory;
	}
}
?>