<?php
/**
 * @version 1.1.0 $Id: usergallery.php 2009-03-25 $
 * @package Joomla
 * @subpackage PhotoMap Gallery
 * @copyright (C) 2009 - 2010 Oh-Taek Im
 * @license GNU/GPL, see LICENCE.php
 * PhotoMap Gallery is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License 2
 * as published by the Free Software Foundation.

 * PhotoMap Gallery is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.

 * You should have received a copy of the GNU General Public License
 * along with PHOTOMAP GALLERY; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 */

// no direct access
defined( '_JEXEC' ) or die( 'Restricted access' );

jimport('joomla.application.component.model');

/**
 * PhotoMap Gallery Component Model
 *
 * @package Joomla
 * @subpackage PhotoMap Gallery
 * @since		1.0
 */
class photomapgalleryModelUserGallery extends JModel
{
	/**
	 * Category id
	 *
	 * @var int
	 */
	var $_id = null;
	
	/**
	 * Categories items Data
	 *
	 * @var mixed
	 */
	var $_data = null;

	/**
	 * Childs
	 *
	 * @var mixed
	 */
	var $_childs = null;
	
	/**
	 * Category data
	 *
	 * @var object
	 */
	var $_category = null;
	
	var $_maincategory = null;

	/**
	 * Categories total
	 *
	 * @var integer
	 */
	var $_total = null;

	var $_mapdata = null;

	var $_vieweddata = null;
	
	var $_newdata = null;
	
	var $_featureddata = null;
	
	var $_viewedtotal = null;
	/**
	 * Constructor
	 *
	 * @since 1.0
	 */
	function __construct()
	{
		parent::__construct();

		global $mainframe;
		$config  	= & GUtil::config();

		// Get the paramaters of the active menu item
		$params = & $mainframe->getParams('com_photomapgallery');
		
		$cid			= JRequest::getInt('cid', 0);

		//get the number of entries from session
		$limit		= $mainframe->getUserStateFromRequest('com_photomapgallery.category.limit', 'limit', $config->imagelimit, 'int');
		
		$limitstart		= JRequest::getInt('limitstart');
		
		$this->setId((int)$cid);

		$this->setState('limit', $limit);
		$this->setState('limitstart', $limitstart);

		// Get the filter request variables
		$this->setState('filter_order', JRequest::getCmd('filter_order', 'i.ordering'));
		$this->setState('filter_order_dir', JRequest::getCmd('filter_order_Dir', 'ASC'));
	}

	/**
	 * Method to set the category id
	 *
	 * @access	public
	 * @param	int	category ID number
	 */
	function setId($id)
	{
		// Set new category ID and wipe data
		$this->_id			= $id;
		//$this->_data		= null;
	}

	/**
	 * Method to get Data
	 *
	 * @access public
	 * @return mixed
	 */
	function getData()
	{
		// Lets load the content if it doesn't already exist
		if (empty($this->_data))
		{
			$query = $this->_buildQuery();
			$this->_data = $this->_getList( $query, $this->getState('limitstart'), $this->getState('limit') );
		}

		return $this->_data;
	}

	/**
	 * Total nr of Categories
	 *
	 * @access public
	 * @return integer
	 */
	function getTotal()
	{
		// Lets load the total nr if it doesn't already exist
		if (empty($this->_total))
		{
			$query = $this->_buildQuery();
			$this->_total = $this->_getListCount($query);
		}

		return $this->_total;
	}

	/**
	 * Builds the query
	 *
	 * @access public
	 * @return string
	 */
	function _buildQuery()
	{
		// Get the WHERE and ORDER BY clauses for the query
		$where		= $this->_buildItemWhere();
		$orderby	= $this->_buildItemOrderBy();

		$query = 'SELECT DISTINCT i.*, (i.rate / (i.rate + i.rate_sum) ) * 100 AS votes,'
		. ' CASE WHEN CHAR_LENGTH(i.alias) THEN CONCAT_WS(\':\', i.id, i.alias) ELSE i.id END as slug'
		. ' FROM #__g_galleryitems AS i'
		. ' LEFT JOIN #__g_cats_item_relations AS rel ON rel.itemid = i.id'
		. ' LEFT JOIN #__g_categories AS c ON c.id = '. $this->_id
		. $where
		. $orderby
		;

		return $query;
	}

	/**
	 * Build the order clause
	 *
	 * @access private
	 * @return string
	 */
	function _buildItemOrderBy()
	{
		$filter_order		= $this->getState('filter_order');
		$filter_order_dir	= $this->getState('filter_order_dir');

		$orderby 	= ' ORDER BY '.$filter_order.' '.$filter_order_dir.', i.ordering';

		return $orderby;
	}

	/**
	 * Method to build the WHERE clause
	 *
	 * @access private
	 * @return array
	 */
	function _buildItemWhere( )
	{
		global $mainframe;

		$user		= & JFactory::getUser();
		$gid		= (int) $user->get('aid');

		// Get the paramaters of the active menu item
		$params 	= & $mainframe->getParams('com_photomapgallery');

		// First thing we need to do is to select only the requested items
		$where = ' WHERE rel.catid = '.$this->_id;
		$where .= ' AND i.published = 1';

		// Second is to only select items assigned to category the user has access to
		$where .= ' AND c.access <= '.$gid;

		/*
		* If we have a filter, and this is enabled... lets tack the AND clause
		* for the filter onto the WHERE clause of the item query.
		*/
		if ($params->get('filter'))
		{
			$filter = JRequest::getString('filter', '', 'request');

			if ($filter)
			{
				// clean filter variables
				$filter	 = $this->_db->getEscaped( trim(JString::strtolower( $filter ) ) );

				$where .= ' AND LOWER( i.title ) LIKE '.$this->_db->Quote( '%'.$this->_db->getEscaped( $filter, true ).'%', false );
			}
		}
		return $where;
	}

	/**
	 * Method to build the Categories query
	 *
	 * @access private
	 * @return array
	 */
	function _buildChildsquery()
	{
		$user 		= &JFactory::getUser();
		$gid		= (int) $user->get('aid');
		$ordering	= 'ordering ASC';

		$where = ' WHERE cc.published = 1';
		$where .= ' AND cc.parent_id = '. $this->_id;
		$where .= ' AND cc.access <= '.$gid;
		$where .= ' AND i.published = 1';
		$where .= ' AND c.id = cc.id';
		
		$query = 'SELECT c.*,'
				. ' CASE WHEN CHAR_LENGTH( c.alias ) THEN CONCAT_WS( \':\', c.id, c.alias ) ELSE c.id END AS slug,'
					. ' ('
					. ' SELECT COUNT( DISTINCT i.id )'
					. ' FROM #__g_galleryitems AS i'
					. ' LEFT JOIN #__g_cats_item_relations AS rel ON rel.itemid = i.id'
					. ' LEFT JOIN #__g_categories AS cc ON cc.id = rel.catid'
					. $where
					. ' GROUP BY cc.id'
					. ')' 
					. ' AS assignedgalleryitems'
				. ' FROM #__g_categories AS c'
				. ' WHERE c.published = 1'
				. ' AND c.parent_id = '. $this->_id
				. ' AND c.userid > 62'
				. ' AND c.access <= '.$gid
				. ' ORDER BY '.$ordering
				;
		
		return $query;
	}
	/**
	 * Method to get the childs of a category
	 *
	 * @access private
	 * @return array
	 */
	function getChilds()
	{
		$query = $this->_buildChildsquery();
		$this->_childs = $this->_getList($query, $this->getState('limitstart'), $this->getState('limit'));

		$count = count($this->_childs);
		for($i = 0; $i < $count; $i++)
		{
			$category =& $this->_childs[$i];

			$category->subcats		= $this->_getsubs( $category->id );
		}

		return $this->_childs;
	}

	/**
	 * Method to build the Categories query
	 * todo: see above and merge
	 *
	 * @access private
	 * @return array
	 */
	function _getsubs($id)
	{
		$user 		= &JFactory::getUser();
		$gid		= (int) $user->get('aid');
		$ordering	= 'ordering ASC';

		$query = 'SELECT *,'
				. ' CASE WHEN CHAR_LENGTH(alias) THEN CONCAT_WS(\':\', id, alias) ELSE id END as slug'
				. ' FROM #__g_categories'
				. ' WHERE published = 1'
				. ' AND parent_id = '. (int)$id
				. ' AND access <= '.$gid
				. ' ORDER BY '.$ordering
				;

		$this->_db->setQuery($query);
		$this->_subs = $this->_db->loadObjectList();

		return $this->_subs;
	}

	/**
	 * Method to load the Category
	 *
	 * @access public
	 * @return array
	 */
	function getCategory()
	{
		//initialize some vars
		$user		= & JFactory::getUser();
		$gid		= (int) $user->get('aid');

		//get categories
		$query = 'SELECT c.*, g.name AS groupname,'
				. ' CASE WHEN CHAR_LENGTH(c.alias) THEN CONCAT_WS(\':\', c.id, c.alias) ELSE c.id END as slug'
				. ' FROM #__g_categories AS c'
				. ' LEFT JOIN #__g_user AS u ON u.userID = c.userid'
				. ' LEFT JOIN #__g_user_groups AS g ON g.id = u.group'
				. ' WHERE c.userid = '.$user->id
				. ' AND c.published = 1'
				. ' AND c.id = '.$this->_id
				. ' AND c.access <= '.$gid
				;

		$this->_db->setQuery($query);
		$this->_category = $this->_db->loadObject();
		
		//check whether category access level allows access
		//additional check
		if ($this->_category->access > $gid)
		{
			JError::raiseError(403, JText::_("ALERTNOTAUTH"));
			return false;
		}

		return $this->_category;
	}
	
	function &getSubCategory()
	{
		//initialize some vars
		$user		= & JFactory::getUser();
		$gid		= (int) $user->get('aid');

		//get categories
		$query = 'SELECT c.*,'
		. ' CASE WHEN CHAR_LENGTH(c.alias) THEN CONCAT_WS(\':\', c.id, c.alias) ELSE c.id END as slug'
		. ' FROM #__g_categories AS c'
		. ' WHERE c.userid = '.$user->id
		. ' AND c.published = 1'
		. ' AND c.parent_id = '.$this->_id
		. ' AND c.access <= '.$gid
		;

		$this->_db->setQuery($query);
		$rows = $this->_db->loadObjectList();

		return $rows;
	}
	
	function getMapData($id)
	{
		// Lets load the content if it doesn't already exist
//		if (empty($this->_mapdata))
		{
//			$this->setId((int)$id);
			$query = $this->_buildMapQuery($id);
			$this->_mapdata = $this->_getList($query);
		}

		return $this->_mapdata;
	}
	
	function _buildMapQuery($id)
	{
		// Get the WHERE and ORDER BY clauses for the query
		$where = ' WHERE rel.catid = '.$id;
		$where .= ' AND i.published = 1';
		$where .= ' AND i.mapdisplay = 1';
		$where .= ' AND i.lat > 0';

		$orderby	= $this->_buildItemOrderBy();

		$query = 'SELECT i.title, i.filename, i.lat, i.lon, i.zoom, i.maptype, i.imagewidth, i.imageheight, c.title as category,'
		. ' CASE WHEN CHAR_LENGTH(i.alias) THEN CONCAT_WS(\':\', i.id, i.alias) ELSE i.id END as slug'
		. ' FROM #__g_galleryitems AS i'
		. ' LEFT JOIN #__g_cats_item_relations AS rel ON rel.itemid = i.id'
		. ' LEFT JOIN #__g_categories AS c ON c.id = '. $id
		. $where
		. $orderby
		;
		
		return $query;
	}
	
	function getViewedTotal()
	{
		// Lets load the total nr if it doesn't already exist
		if (empty($this->_viewedtotal))
		{
			$query = $this->_buildViewedQuery();
			$this->_viewedtotal = $this->_getListCount($query);
		}

		return $this->_viewedtotal;
	}
	
	function getViewedData()
	{
		// Lets load the content if it doesn't already exist
		if (empty($this->_vieweddata))
		{
			$query = $this->_buildViewedQuery();
			$this->_vieweddata = $this->_getList( $query, $this->getState('limitstart'), $this->getState('limit') );
		}

		return $this->_vieweddata;
	}
	
	function _buildViewedQuery()
	{
		$user 		= &JFactory::getUser();
		$gid		= (int) $user->get('aid');
		
		// Get the WHERE and ORDER BY clauses for the query
		$where = ' WHERE i.published = 1';
		$where .= ' AND c.access <= '.$gid;
		
//		$limit 		= JRequest::getVar('limit', 100);
		$orderby 	= ' ORDER BY i.hits DESC';

		$query = 'SELECT i.*, c.title AS cattitle,'
		. ' CASE WHEN CHAR_LENGTH(i.alias) THEN CONCAT_WS(\':\', i.id, i.alias) ELSE i.id END as slug'
//		. ' CASE WHEN CHAR_LENGTH(c.alias) THEN CONCAT_WS(\':\', c.id, c.alias) ELSE c.id END as catslug'
		. ' FROM #__g_galleryitems AS i'
		. ' LEFT JOIN #__g_cats_item_relations AS rel ON rel.itemid = i.id'
		. ' LEFT JOIN #__g_categories AS c ON c.id = rel.catid'
		. $where
		. $orderby
		;

		return $query;
	}
	
	function getNewData()
	{
		// Lets load the content if it doesn't already exist
		if (empty($this->_newdata))
		{
			$query = $this->_buildNewQuery();
			$this->_newdata = $this->_getList( $query, $this->getState('limitstart'), $this->getState('limit') );
		}

		return $this->_newdata;
	}
	
	function _buildNewQuery()
	{
		// Get the WHERE and ORDER BY clauses for the query
//		$filter_order		= $this->getState('filter_order');
//		$filter_order_dir	= $this->getState('filter_order_dir');

		$orderby 	= ' ORDER BY i.id DESC';
		
//		$where		= $this->_buildItemWhere();
//		$orderby	= $this->_buildItemOrderBy();

		$query = 'SELECT i.*, c.title AS cattitle,'
		. ' CASE WHEN CHAR_LENGTH(i.alias) THEN CONCAT_WS(\':\', i.id, i.alias) ELSE i.id END as slug'
		. ' FROM #__g_galleryitems AS i'
		. ' LEFT JOIN #__g_cats_item_relations AS rel ON rel.itemid = i.id'
		. ' LEFT JOIN #__g_categories AS c ON c.id = rel.catid'
		. ' WHERE i.published = 1'
		. $orderby
		;

		return $query;
	}
	
	function getFeaturedData()
	{
		// Lets load the content if it doesn't already exist
		if (empty($this->_featureddata))
		{
			$query = $this->_buildFeaturedQuery();
			$this->_featureddata = $this->_getList( $query, $this->getState('limitstart'), $this->getState('limit') );
		}

		return $this->_featureddata;
	}
	
	function _buildFeaturedQuery()
	{
		// Get the WHERE and ORDER BY clauses for the query
//		$filter_order		= $this->getState('filter_order');
//		$filter_order_dir	= $this->getState('filter_order_dir');

		$orderby 	= ' ORDER BY i.title ASC';
		
//		$where		= $this->_buildItemWhere();
//		$orderby	= $this->_buildItemOrderBy();

		$query = 'SELECT i.*, c.title AS cattitle,'
		. ' CASE WHEN CHAR_LENGTH(i.alias) THEN CONCAT_WS(\':\', i.id, i.alias) ELSE i.id END as slug'
//		. ' CASE WHEN CHAR_LENGTH(c.alias) THEN CONCAT_WS(\':\', c.id, c.alias) ELSE c.id END as catslug'
		. ' FROM #__g_galleryitems AS i'
		. ' LEFT JOIN #__g_cats_item_relations AS rel ON rel.itemid = i.id'
		. ' LEFT JOIN #__g_categories AS c ON c.id = rel.catid'
		. ' WHERE i.featured = 1'
		. $orderby
		;

		return $query;
	}
	
	function _loadCategory()
	{
		// Lets load the category if it doesn't already exist
		if (empty($this->_category))
		{
			$query = 'SELECT *'
					. ' FROM #__g_categories'
					. ' WHERE id = '.$this->_id
					;
			$this->_db->setQuery($query);
			$this->_category = $this->_db->loadObject();

			return (boolean) $this->_category;
		}
		return true;
	}
	
	function store($data)
	{
		$category  =& $this->getTable('g_categories', '');

		// bind it to the table
		if (!$category->bind($data)) {
			$this->setError(500, $this->_db->getErrorMsg() );
			return false;
		}

		if (!$category->id) {
			$category->ordering = $category->getNextOrder();
		}
		
		// Make sure the data is valid
		if (!$category->check()) {
			$this->setError($category->getError());
			return false;
		}

		// Store it in the db
		if (!$category->store()) {
			$this->setError(500, $this->_db->getErrorMsg() );
			return false;
		}
		
		$this->_category	=& $category;
		
		return $category->id;
	}
	
	function isCheckedOut( $uid=0 )
	{
		if ($this->_loadCategory())
		{
			if ($uid) {
				return ($this->_category->checked_out && $this->_category->checked_out != $uid);
			} else {
				return $this->_category->checked_out;
			}
		} elseif ($this->_id < 1) {
			return false;
		} else {
			JError::raiseWarning( 0, 'UNABLE LOAD DATA');
			return false;
		}
	}
	
	function checkout($uid = null)
	{
		if ($this->_id)
		{
			// Make sure we have a user id to checkout the item with
			if (is_null($uid)) {
				$user	=& JFactory::getUser();
				$uid	= $user->get('id');
			}
			// Lets get to it and checkout the thing...
			$category = & JTable::getInstance('g_categories', '');
			if(!$category->checkout($uid, $this->_id)) {
				$this->setError($this->_db->getErrorMsg());
				return false;
			}

			return true;
		}
		return false;
	}
	
	function checkin()
	{
		if ($this->_id)
		{
			$category = & JTable::getInstance('g_categories', '');
			return $category->checkin($this->_id);
		}
		return false;
	}
	
	function getMainCategory($userid)
	{
		//get categories
		$query = 'SELECT c.*, g.avatar AS useravatar,'
				. ' CASE WHEN CHAR_LENGTH(c.alias) THEN CONCAT_WS(\':\', c.id, c.alias) ELSE c.id END as slug'
				. ' FROM #__g_categories AS c'
				. ' LEFT JOIN #__g_user AS g ON g.userID = c.userid'
				. ' WHERE c.parent_id = 0'
				. ' AND c.published = 1'
				. ' AND c.userid = '.$userid
				;

		$this->_db->setQuery($query);
		$this->_maincategory = $this->_db->loadObject();

		return $this->_maincategory;
	}
}
?>